#
# spec file for package libstorage-ng
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname %{name}1
Name:           libstorage-ng
Version:        4.2.76
Release:        lp152.2.3.1
Summary:        Library for storage management
License:        GPL-2.0-only
Group:          System/Libraries
Url:            http://github.com/openSUSE/libstorage-ng
Source:         %{name}-%{version}.tar.xz
%if 0%{?suse_version} >= 1330
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_test-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  grep
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  ruby
BuildRequires:  ruby-devel
%if 0%{?suse_version} == 1315
# Using rubygem(test-unit) does not work since ruby2.1-stdlib claims to
# provide rubygem(test-unit). But that is plain wrong. The version in
# ruby2.1-stdlib does not provide the function assert_raise_kind_of.
BuildRequires:  ruby2.1-rubygem-test-unit
%endif
%if 0%{?fedora}
BuildRequires:  rubygem-test-unit
%endif
BuildRequires:  swig >= 3.0.3
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  libjson-c-devel
BuildRequires:  pkgconfig(python3)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains libstorage-ng, a library for storage management.

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%package -n %{libname}
Summary:        Library for storage management
Group:          System/Libraries
Recommends:     %{name}-lang
Requires:       coreutils
Suggests:       cryptsetup
Requires:       device-mapper
Suggests:       dmraid
Requires:       lsscsi >= 0.26
Suggests:       lvm2
Suggests:       mdadm >= 3.3
Suggests:       multipath-tools
Requires:       parted >= 3.2
Requires:       pkgconfig
Requires:       util-linux >= 2.16
Requires:       pkgconfig(udev)
Obsoletes:      %{libname} < %{version}
Obsoletes:      libstorage %(echo `seq -s " " -f "libstorage%.f" 9`)
%ifarch s390 s390x
Requires:       s390-tools
%endif
# Old version of libdmraid cannot be used. Upgrading from SLE11 to SLE15
# does not remove old version, so it needs to be marked as conflict.
# For more info, see https://bugzilla.suse.com/show_bug.cgi?id=1088570#c35
Conflicts:      libdmraid.so.1.0.0.rc16(libdmraid.so.1.0.0.rc16)(64bit)

%description -n %{libname}
This package contains libstorage-ng, a library for storage management.

%package devel
Summary:        Header files and documentation for libstorage-ng
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}
Requires:       gcc-c++
Requires:       libstdc++-devel
Requires:       pkgconfig
Requires:       pkgconfig(libxml-2.0)

%description devel
This package contains header files and documentation for developing with
libstorage-ng.

%package python3
Summary:        Python bindings for libstorage-ng
Group:          System/Libraries
Requires:       %{libname} = %{version}
Obsoletes:      libstorage-python

%description python3
This package contains Python bindings for libstorage-ng.

%package ruby
Summary:        Ruby bindings for libstorage-ng
Group:          System/Libraries
Requires:       %{libname} = %{version}
Obsoletes:      libstorage-ruby

%description ruby
This package contains Ruby bindings for libstorage-ng.

%package utils
Summary:	Utils for libstorage-ng
Group:		Development/Tools/Other
Recommends:	graphviz
Recommends:	ImageMagick

%description utils
This package contains utils for libstorage-ng.

%package integration-tests
Summary:        Integration tests for libstorage-ng
Group:          Development/Tools/Other
Requires:       libstorage-ng-python3

%description integration-tests
This package contains integration tests for libstorage-ng.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -DNDEBUG"
export CXXFLAGS="%{optflags} -DNDEBUG"

autoreconf -fvi

%configure \
   --disable-static \
   --disable-silent-rules
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check VERBOSE=1 LOCALEDIR=%{buildroot}%{_datadir}/locale

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.pyc" -delete -print

install -d -m 755 %{buildroot}/run/libstorage-ng
touch %{buildroot}/run/libstorage-ng/lock

%fdupes -s %{buildroot}

%find_lang libstorage-ng

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{name}-lang -f libstorage-ng.lang
%defattr(-,root,root)

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS
%license LICENSE
%{_libdir}/libstorage-ng.so.*
%ghost /run/libstorage-ng

%files devel
%defattr(-,root,root)
%{_libdir}/libstorage-ng.so
%{_includedir}/storage
%dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/*

%files python3
%defattr(-,root,root)
%{python3_sitelib}/storage.py*
%attr(755,root,root) %{python3_sitearch}/_storage.so

%files ruby
%defattr(-,root,root)
%{rb_vendorarch}/storage.so

%files utils
%defattr(-,root,root)
%dir %{_libexecdir}/libstorage-ng
%{_libexecdir}/libstorage-ng/utils

%files integration-tests
%defattr(-,root,root)
%{python3_sitelib}/storageitu.py*
%dir %{_libexecdir}/libstorage-ng
%{_libexecdir}/libstorage-ng/integration-tests

%changelog
* Mon Jun 29 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#754
- added UsedFeature for NVMe disks (for bsc#1172866)
- 4.2.76
* Thu May  7 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#734
- merge gh#openSUSE/libstorage-ng#732
- merge gh#openSUSE/libstorage-ng#717
- merge gh#openSUSE/libstorage-ng#715
- track device block size when creating an Md RAID (bsc#1164295)
- simplify combining disks with different block sizes into RAID
  (bsc#1164295)
- add block_size check for Md::add_device()
- update doc on RAID block size
- ignore clusterd VGs also in vgchange command (bsc#1161775)
- ignore umount/swapoff failure if it looks inactive already
  (bsc#1168615)
- fixed typo
- 4.2.75
* Mon Apr 20 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#719
- document device block size handling (RAID, LVM, BTRFS)
- document device block size handling (BCACHE)
- clarify LV block size remark
- 4.2.74
* Fri Apr 17 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#720
- fix unit test
- 4.2.73
* Wed Apr  1 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#718
- allow control over environment variables
- query number of partition slots from parted
- respect number of partition slots reported by parted for GPT
  (bsc#1161783)
- run travis with "--privileged" to avoid permissions error
- 4.2.72
* Wed Mar 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#714
- simplify combining disks with different block sizes into RAID
  (bsc#1164295)
- Revert "add tests for adjust_block_size()"
- Revert "add adjust_block_size() method to Region class
  (bsc#1164295)"
- update doc
- 4.2.71
* Wed Mar 25 2020 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#713
- Make BlkDevice::possible_mount_bys public (for bsc#1166096)
- Increase minor so version
- 4.2.70
* Wed Mar 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#712
- update doc on RAID block size
- 4.2.69
* Fri Mar 13 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#711
- increase minor so version
- 4.2.68
* Fri Mar 13 2020 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#709
- add adjust_block_size() method to Region class (bsc#1164295)
- track device block size when creating an Md RAID (bsc#1164295)
- add tests for adjust_block_size()
- add block_size check for Md::add_device()
- 4.2.67
* Thu Mar  5 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#708
- merge gh#openSUSE/libstorage-ng#707
- Translated using Weblate (Finnish) (bsc#1149754)
- Add option for ignoring clustered LVM
- Update lib version
- Ignore clustered LVM
- Revert "Add option for ignoring clustered LVM"
- Revert "Update lib version"
- Revert "Translated using Weblate (Finnish)" (bsc#1149754)
- Sync branches (SLE-15-SP1)
- 4.2.66
* Thu Feb 20 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish) (bsc#1149754)
- 4.2.65
* Wed Feb 19 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian) (bsc#1149754)
- 4.2.64
* Wed Feb 19 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (French) (bsc#1149754)
* Mon Feb 17 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan)) (bsc#1149754)
- 4.2.63
* Sun Feb 16 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China)) (bsc#1149754)
- 4.2.62
* Tue Feb 11 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#706
- added support for btrfs RAID1C{3,4}
- increase minor so version
- 4.2.61
* Thu Feb  6 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#705
- fixed failure message
- 4.2.60
* Wed Feb  5 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#704
- added being and end function to ProbeCallbacks
- extended documentation
- 4.2.59
* Wed Feb  5 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#703
- Remove OutputProcessor class
* Mon Feb  3 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#702
- added callback for missing commands during probing
- added unit tests
- improved readability of defines for external commands
- simplyfied code
- fixed typo
- added probing callback for missing commands
- 4.2.58
* Mon Jan 20 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil)) (bsc#1149754)
- 4.2.57
* Fri Jan 17 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#701
- check for existence of lvm vg before using it (bsc#1161191)
- 4.2.56
* Thu Jan 16 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish) (bsc#1149754)
- 4.2.55
* Wed Jan 15 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#700
- merge gh#openSUSE/libstorage-ng#699
- Unmount when mount point was active
- Mount when mount point is active
- Bump version
- Add comments
- Fix mount and unmount (forward port)
- 4.2.54
* Tue Jan 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak) (bsc#1149754)
- 4.2.53
* Tue Jan 14 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#698
- remove default option '-m crc=1' for mkfs.xfs
- use udevadm from /usr/bin instead of /sbin (bsc#1160890)
- 4.2.52
* Tue Jan 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (German) (bsc#1149754)
- 4.2.51
* Tue Jan 14 2020 freek@opensuse.org
- Translated using Weblate (Dutch) (bsc#1149754)
* Tue Jan 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan) (bsc#1149754)
* Mon Jan 13 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil)) (bsc#1149754)
- 4.2.50
* Mon Jan 13 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese) (bsc#1149754)
* Mon Jan 13 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech) (bsc#1149754)
* Thu Jan  9 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#696
- updated pot and po files
- 4.2.49
* Thu Jan  9 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#697
- merge gh#openSUSE/libstorage-ng#693
- Translated using Weblate (Estonian) (bsc#1149754)
- Translated using Weblate (Finnish) (bsc#1149754)
- Add unit tests
- Bump version
- Ensure default to 0 for optional columns
- Improve test
- Revert "Translated using Weblate (Finnish)" (bsc#1149754)
- Revert "Translated using Weblate (Estonian)" (bsc#1149754)
- Allow optional fstab columns (merge SLE-15-SP1)
- 4.2.48
* Thu Jan  9 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#695
- added probing of BitLocker (bsc#1159318)
- added unit test
- fixed message
- add minimal support for BitLocker
- 4.2.47
* Wed Jan  8 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#694
- Fix partition id when creating partition
- Bump version
- 4.2.46
* Tue Jan  7 2020 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#691
- Add method to get partition id name
- Bump version
- Add note
- Partition Id names
- 4.2.45
* Fri Jan  3 2020 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#692
- improved sort-key for block devices (for bsc#1140018)
- extended documentation
- 4.2.44
* Thu Dec 19 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#690
- provide sort-key for device name (for bsc#1140018)
- adapted utility programs to changes in networkx 2.4
- removed obsolete variable
- 4.2.43
* Wed Dec 18 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish) (bsc#1149754)
- 4.2.42
* Sun Dec 15 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (German) (bsc#1149754)
- 4.2.41
* Thu Dec 12 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#689
- use ranks in graphviz output to ease readability (bsc#1149154)
- reduce test devicegraph to required information
- 4.2.40
* Thu Dec 12 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#688
- Add new callbacks for LUKS activation
- Bump version
- Add specialized Luks callbacks
- 4.2.39
* Tue Dec 10 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#687
- use correct size for btrfs resize command during shrink (bsc#1157762)
- 4.2.38
* Thu Dec  5 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#686
- extended some testcases to also check executed commands
- merged testsuite/actions into testsuite/dependencies
- added tests for shrinking btrfs
- extended tests
- extended and added testcases
- 4.2.37
* Thu Dec  5 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#685
- added testcases for growing btrfs
- check that all command and file mockups are used
- added testcases for growing and shrinking ext4
- added testcases for resizing filesystems
- 4.2.36
* Tue Dec  3 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#684
- list all devices in subvolume actions (bsc#1152523)
- consistent list of block devices in compound actions
- removed unneeded use of c_str
- updated explanations for translators
- show all block devices for action texts of btrfs subvolumes
- 4.2.35
* Mon Dec  2 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.34
* Mon Dec  2 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#683
- extended unit test (bsc#1135341)
- updated documentation (bsc#1149148)
- added internal check
- fixed typo
- 4.2.33
* Fri Nov 29 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#682
- merge gh#openSUSE/libstorage-ng#681
- Translated using Weblate (Danish) (bsc#1149754)
- Translated using Weblate (Estonian) (bsc#1149754)
- fixed handling of btrfs subvolumes with special (regex control)
  characters in the path (bsc#1135341)
- 4.2.32
* Thu Nov 28 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#680
- fixed escaping of graphviz escString (bsc#1157916)
- 4.2.31
* Wed Nov 27 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.30
* Tue Nov 26 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#679
- use estimation from resize2fs for min size of ext4 (bsc#1149148)
- use 64bit feature forr max size of ext4
- separated parser for ntfsresize output
- added example programs
- added unit tests
- extended exception logging
- cleanup
- consistent naming of example programs
- changed path of resize2fs to /usr/sbin
- improved calculation of resize information
- 4.2.29
* Tue Nov 26 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#678
- Only join entries when path matches
- Select the most reasonable mount point
- Add unit tests
- Update version
- Bind mount workaround
- 4.2.28
* Wed Nov 13 2019 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#677
- Make default mount_options public (needed for jsc#SLE-7687)
- Bump version
- Rename Mountable::Impl#get_default_mount_options
- Split MountPoint#set_default_mount_options into pieces (needed
  for jsc#SLE-7687)
- 4.2.27
* Sun Nov 10 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.26
* Sat Nov  9 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.25
* Fri Nov  8 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.24
* Thu Nov  7 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.23
* Wed Nov  6 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.22
* Wed Nov  6 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.21
* Tue Nov  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.20
* Thu Oct 31 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#676
- handle is_permanent() in possible_mount_bys() (bsc#1155566)
- simplified code
- 4.2.19
* Mon Oct 28 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.2.18
* Fri Oct 18 2019 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#675
- Log messages about the mount_by fallback are just warnings
  (related to bsc#1151075)
- 4.2.17
* Sat Oct 12 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan)) (bsc#1149754)
- 4.2.16
* Fri Oct 11 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#674
- cache luks activation information (for bsc#1129496)
- use password from LUKS activation for resize (bsc#1153871)
- extended integration test
- fixed typos
- 4.2.15
* Mon Sep 30 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#673
- parse cipher and key size in cryptsetup output
- added cipher and key size to Encryption (for jsc#SLE-7376)
- probe sector size for Encryption
- extended documentation
- added sanity check
- coding style
- added test case for paes cipher
- handle cipher and key size for encryption
- 4.2.14
* Thu Sep 26 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#672
- Add open_options
- Bump version
- Extra options to open encryption
- 4.2.13
* Thu Sep 26 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish) (bsc#1149754)
- 4.2.12
* Tue Sep 10 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan) (bsc#1149754)
- 4.2.11
* Mon Sep  9 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#671
- added integration test
- 4.2.10
* Fri Sep  6 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#670
- added notes
- 4.2.9
* Thu Sep  5 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#668
- removed unneeded code
- cleanup integration tests
- code cleanup
- 4.2.8
* Wed Sep  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.2.7
* Wed Sep  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.2.6
* Wed Sep  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
* Wed Sep  4 2019 freek@opensuse.org
- Translated using Weblate (Dutch)
* Wed Sep  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
* Wed Sep  4 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#667
- update pot and po files
- 4.2.5
* Wed Sep  4 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#666
- added note
- use dev_t to save major and minor numbers
- improved unit test
- coding style
- consistent function name
- added support for plain encryption (bsc#1088641)
- added unit test
- added integration tests
- 4.2.4
* Mon Sep  2 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#665
- extended documentation
- 4.2.3
* Sun Aug 25 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.2.2
* Fri Aug 23 2019 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#663
- update packaging documentation
- 4.2.1
* Fri Aug 23 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#662
- merge gh#openSUSE/libstorage-ng#661
- Adapt Dockerfile for SLE-15-SP1
- Translated using Weblate (Slovak)
- Translated using Weblate (Catalan)
- Translated using Weblate (Czech)
- Translated using Weblate (Japanese)
- Translated using Weblate (Arabic)
- Translated using Weblate (Chinese (China))
- Translated using Weblate (Chinese (Taiwan))
- Translated using Weblate (Dutch)
- Translated using Weblate (French)
- Translated using Weblate (German)
- Translated using Weblate (Hungarian)
- Translated using Weblate (Italian)
- Translated using Weblate (Korean)
- Translated using Weblate (Polish)
- Translated using Weblate (Russian)
- Translated using Weblate (Spanish)
- Translated using Weblate (Swedish)
- Translated using Weblate (Portuguese (Brazil))
- Translated using Weblate (Finnish)
- Fix dectection of surrounding region (bsc#1146686)
- Bump lib version
- Fix surrounding detection
- Revert "Translated using Weblate (Catalan)"
- Revert "Translated using Weblate (Finnish)"
- Revert "Translated using Weblate (Dutch)"
- Revert "Translated using Weblate (Portuguese (Brazil))"
- Revert "Translated using Weblate (Swedish)"
- Revert "Translated using Weblate (Spanish)"
- Revert "Translated using Weblate (Russian)"
- Revert "Translated using Weblate (Polish)"
- Revert "Translated using Weblate (Korean)"
- Revert "Translated using Weblate (Italian)"
- Revert "Translated using Weblate (Hungarian)"
- Revert "Translated using Weblate (German)"
- Revert "Translated using Weblate (French)"
- Revert "Translated using Weblate (Chinese (Taiwan))"
- Revert "Translated using Weblate (Chinese (China))"
- Revert "Translated using Weblate (Arabic)"
- Revert "Translated using Weblate (Japanese)"
- Revert "Translated using Weblate (Czech)"
- Revert "Translated using Weblate (Slovak)"
- Revert "Adapt Dockerfile for SLE-15-SP1"
- Merge SLE-15-SP1
- 4.2.0
* Sat Aug 17 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.145
* Wed Aug  7 2019 antoine.belvire@opensuse.org
- Translated using Weblate (French)
- 4.1.144
* Tue Jul 30 2019 medwin@opensuse.org
- Translated using Weblate (Indonesian)
- 4.1.143
* Mon Jul 29 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#660
- added functions to query existance of holders
- 4.1.142
* Fri Jul 26 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#659
- added parser for 'cryptsetup luksDump'
- added example
- added support for LUKS2
- extended documentation
- coding style
- extended integration tests
- fixed documentation
- fixed typo
- relaxed parser for whitespace changes
- LUKS2 support
- 4.1.141
* Wed Jul 10 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#658
- probe zone model for disks
- added unit test
- avoid compiler warning
- coding style
- 4.1.140
* Mon Jul  8 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#657
- extended documentation
- 4.1.139
* Thu Jul  4 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#656
- improve sorting of pmem devices
- 4.1.138
* Wed Jul  3 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 4.1.137
* Sun Jun 30 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 4.1.136
* Sat Jun 29 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.135
* Thu Jun 27 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.134
* Wed Jun 26 2019 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.1.133
* Tue Jun 25 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.1.132
* Tue Jun 25 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 4.1.131
* Tue Jun 25 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.1.130
* Tue Jun 25 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#655
- allow to customize style of graphviz output
- use new style api
- added examples for style api usage
- coding style
- added unit test
- 4.1.129
* Thu Jun  6 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#654
- updated pot and po files
- 4.1.128
* Thu Jun  6 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#653
- improve filesystem related commit action messages
- added unit test
- added integration test
- removed unneeded include statement
* Tue Jun  4 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#652
- added unit test for LVM over MD
- 4.1.127
* Mon Jun  3 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#651
- extended fstab handling for multiple devices btrfs
- added unit test
- fixed documentation
- 4.1.126
* Mon May 27 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#650
- sort block devices when creating btrfs (needed in testsuite)
- 4.1.125
* Fri May 24 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#649
- use devid from devicegraph when resizing btrfs
- extended integration test
- added note
- fix resizing btrfs on e.g. LVM
- 4.1.124
* Thu May 23 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#648
- allow to reuse commands and files in mockup files
- read sub uuid in blkid output
- updated devicegraphs
- add id to FilesystemUser
- removed obsolete setenv calls to enable multiple devices btrfs
- work on btrfs multiple device support
- 4.1.123
* Wed May 22 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#647
- Enable multi-device Btrfs probing by default
- Bump lib version
- Enable multi-device Btrfs by default
- 4.1.122
* Tue May 21 2019 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#646
- Initial changes
- Rename auxiliary struct
- Block shrink multi-device Btrfs
- Adapt action text when growing multi-device Btrfs
- Add integration test
- Bump lib version
- Resize multi-device Btrfs
- 4.1.121
* Thu May  9 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#645
- extended documentation
- 4.1.120
* Thu May  2 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Dutch)
- Translated using Weblate (Finnish)
- 4.1.119
* Tue Apr 30 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#644
- added unit test
- added integration tests
- removed unneeded virtual specifier
- wait for block device
- moved integration tests
- added note
- allow to add devices to existing btrfs (for jsd#SLE-3877)
- 4.1.118
* Fri Apr 26 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#643
- extended documentation
- 4.1.117
* Fri Apr 26 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#642
- added documentation about multiple devices btrfs
- added example
- 4.1.116
* Thu Apr 25 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#641
- handle mixed mode in output of 'btrfs filesystem df'
- 4.1.115
* Thu Apr 25 2019 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#640
- parse UUID in output of mkfs.btrfs
- fixed exception message
- 4.1.114
* Tue Apr 23 2019 lslezak@suse.cz
- merge gh#openSUSE/libstorage-ng#639
- Use the Docker image from OBS
- 4.1.113
* Thu Apr 18 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Indonesian)
- 4.1.112
* Thu Apr 18 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#638
- parse devid in output of 'btrfs filesystem show'
- reuse predefined regex
- 4.1.111
* Wed Apr 17 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#637
- extended documentation
- changed wording
- 4.1.110
* Tue Apr 16 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#636
- handle btrfs raid levels during create
- added unit test
- fixed typo
- 4.1.109
* Mon Apr 15 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#635
- handle multiple devices for btrfs subvolumes
- 4.1.108
* Thu Apr 11 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#634
- added parser for 'btrfs filesystem df'
- probe btrfs with multiple devices
- updated unit test
- added unit test
- added integration tests
- extended documentation
- added pre-check for btrfs
- added checks for nullptr
- renamed variable (that really ties the function together)
- simplyfied interface
- coding style and cleanup
- work on btrfs with multiple devices
- 4.1.107
* Fri Apr  5 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#633
- make get_displayname available (to_s is overridden by use_ostream)
- added unit tests
- coding style
- fixed class names
- make get_displayname() available in ruby
- 4.1.106
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 4.1.105
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 4.1.104
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Polish)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
* Thu Apr  4 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
* Sat Mar 23 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Arabic)
- Translated using Weblate (Catalan)
- Translated using Weblate (Chinese (China))
- Translated using Weblate (Chinese (Taiwan))
- Translated using Weblate (Czech)
- Translated using Weblate (Dutch)
- Translated using Weblate (French)
- Translated using Weblate (German)
- Translated using Weblate (Hungarian)
- Translated using Weblate (Italian)
- Translated using Weblate (Japanese)
- Translated using Weblate (Korean)
- Translated using Weblate (Polish)
- Translated using Weblate (Portuguese (Brazil))
- Translated using Weblate (Russian)
- Translated using Weblate (Slovak)
- Translated using Weblate (Spanish)
- Translated using Weblate (Swedish)
- 4.1.103
* Thu Mar 21 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#630
- fix compilation with -O0
- 4.1.102
* Sat Mar 16 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.101
* Fri Mar 15 2019 sbrabec@suse.cz
- Translated using Weblate (Galician)
- Translated using Weblate (Portuguese (Brazil))
- Translated using Weblate (German)
- Translated using Weblate (Polish)
- 4.1.100
* Wed Mar 13 2019 schubi@suse.de
- Unifying name Bcache/bcache to bcache (#629)
- 4.1.99
* Tue Mar 12 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#628
- handle topology for Partition and Luks
- added unit test for bsc#1121129
- improved calculation of usable size for LVM PVs (bsc#1121129)
- 4.1.98
* Tue Mar 12 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#625
- moved topology from PartitionableImpl to BlkDeviceImpl
- added get_sysfs_file to BlkDeviceImpl
- use new get_sysfs_file
- added save_to_string to XmlFile (for debugging)
- read pe_start from pvs command
- coding style
- enable logging
- added pe_start to LvmPvImpl
- added get_usable_size() to LvmPv
- added unit test for LvmPv::get_usable_size()
- updated hyper link
- added documentation
- preparations for bsc#1121129
- 4.1.97
* Tue Mar  5 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#621
- handle entries in crypttab whose block device do not exist
  (bsc#1123342)
- added unit test
- added documentation
- added explanation
- renamed variable
- 4.1.96
* Thu Feb 28 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#620
- extended documentation
- 4.1.95
* Wed Feb 27 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#619
- disable parted-sector-bug workaround on virtio-blk DASDs
  (bsc#1112037)
- avoid empty nodes in mockup files
- extended testsuite helper TsCmpActiongraph
- added unit tests
- throw exception based on Exception class
- enable verbose output of checks during build
- 4.1.94
* Mon Feb 25 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#618
- updated pot and po files
- 4.1.93
* Mon Feb 25 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#617
- extended parser for lvs command
- added function to join Texts
- added unit tests
- use callback to report unsupported logical volumes (bsc#1099744)
- coding style
- allow to ignore errors during in probe utility
- consistent message style
- added function to join names of block devices
- improved messages for creating volume groups and mds
- consistent naming style
- use new join function in message about deleting filesystems
- fixed typo
- 4.1.92
* Wed Feb 20 2019 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#615
- Workaround upgrade with multiple mout points per block device
  (bsc#1118865)
- 4.1.91
* Wed Feb 20 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#616
- added debugging code
- extended unit test
- 4.1.90
* Mon Feb 18 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#613
- Rename method
- Add method for removing a bcache cset
- Add actions to modify an existing bcache
- Increase minor version
- Fix error messages
- Small fixes
- Allow to modify Bcache devices
- 4.1.89
* Tue Feb 12 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#614
- detect DASDs using virtio-blk (bsc#1112037)
- added unit test
- avoid copying objects
- 4.1.88
* Mon Feb 11 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Dutch)
- Translated using Weblate (Slovak)
- 4.1.87
* Mon Feb 11 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#612
- Fix dead links to old libstorage in the documentation
* Thu Feb  7 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Catalan)
- Translated using Weblate (Chinese (China))
- Translated using Weblate (Czech)
- Translated using Weblate (Danish)
- Translated using Weblate (Japanese)
- Translated using Weblate (Russian)
- Translated using Weblate (Slovak)
- Translated using Weblate (Spanish)
- 4.1.86
* Tue Feb  5 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#611
- Remove setters for non-permanent stored values
- Extend Bcache API with helper methods
- Use bcache command
- Increase minor version
- 4.1.85
* Sat Feb  2 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Swedish)
- Translated using Weblate (Chinese (Taiwan))
- Translated using Weblate (Arabic)
- Translated using Weblate (Dutch)
- Translated using Weblate (French)
- Translated using Weblate (German)
- Translated using Weblate (Hungarian)
- Translated using Weblate (Korean)
- Translated using Weblate (Polish)
- Translated using Weblate (Russian)
- 4.1.84
* Fri Feb  1 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#610
- check for some storage signatures next to partition tables
  (bsc#1115807)
- added unit test
- increase patchlevel
- updated pot and po files
- 4.1.83
* Thu Jan 31 2019 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#609
- added roles to class MdadmDetail
- probe devices order for MD RAIDs (bsc#1083542)
- extended documentation
- check for duplicate entries in mockup files
- updated pot and po files
- added callback recorder for probe callbacks
- probe sort-key for device of MD RAIDs
- 4.1.82
* Thu Jan 31 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#608
- Throw better exceptions
- 4.1.81
* Wed Jan 30 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#607
- Add support for probing Flash-only bcache
- Adapt testsuite
- Add test for Flash-only bcache probing
- CompoundAction: add helper method
- Adapt bcache formatter
- Add tests
- Add bcache doc
- Update lib version
- Add support for flash-only bcache (with ABI compatibility)
- 4.1.80
* Fri Jan 25 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 4.1.79
* Wed Jan 23 2019 schubi@suse.de
- merge gh#openSUSE/libstorage-ng#606
- Evaluating correct block size for DASD devices. (Workaround for a
  parted bug). (bsc#1089554)
- 4.1.78
* Mon Jan 21 2019 weblate-noreply@opensuse.org
- Translated using Weblate (Indonesian)
- Translated using Weblate (Spanish)
- 4.1.77
* Fri Jan 18 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#605
- merge gh#openSUSE/libstorage-ng#604
- Relax check for luks correctness bsc#1120070, bsc#1101870
- Unit tests for the fix of bsc#1120070, bsc#1101870
- Merge to master: Relax check for luks correctness bsc#1120070,
  bsc#1101870
- 4.1.76
* Fri Jan  4 2019 Vojtech.Zeisek@opensuse.org
- Translated using Weblate (Czech)
- 4.1.75
* Wed Dec 19 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 4.1.74
* Mon Dec 10 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#602
- merge gh#openSUSE/libstorage-ng#601
- merge gh#openSUSE/libstorage-ng#600
- merge gh#openSUSE/libstorage-ng#599
- use exceptions to handle errors
- Create crypttab with proper permissions (bsc#1059972)
- Create lock with proper permissions (bsc#1059972)
- Create log file with proper permissions (bsc#1059972)
- Add missing quoting (bsc#1059972)
- Improvements from review
- Backport: Fix audit issues
- avoid thread unsafe strerror function
- Backport: avoid thread unsafe strerror function
- Merge SLE-15-GA
- 4.1.73
* Sat Dec  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 4.1.72
* Wed Dec  5 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#598
- avoid thread unsafe strerror function
- 4.1.71
* Wed Dec  5 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#597
- Create crypttab with proper permissions (bsc#1059972)
- Create lock with proper permissions (bsc#1059972)
- Create log file with proper permissions (bsc#1059972)
- Add missing quoting (bsc#1059972)
- Improvements from review
- Fix audit issues
- 4.1.70
* Sun Dec  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish)
- 4.1.69
* Sun Dec  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.68
* Fri Nov 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 4.1.67
* Wed Nov 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 4.1.66
* Wed Nov 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 4.1.65
* Sun Nov 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.64
* Sat Nov 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.63
* Sat Nov 24 2018 antoine.belvire@opensuse.org
- Translated using Weblate (French)
- 4.1.62
* Sat Nov 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
* Fri Nov 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.1.61
* Fri Nov 23 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.1.60
* Fri Nov 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 4.1.59
* Fri Nov 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.1.58
* Fri Nov 23 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#596
- updated pot and po files
* Fri Nov 23 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#595
- improved sformat to be type safe and handle Text properly
- properly translate partition type texts
- properly translate devices size texts
- removed now obsolete c_str calls
- added comment for translators
- reduce format warning level
- fixed typo
- 4.1.57
* Fri Nov 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
* Wed Nov 21 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 4.1.56
* Wed Nov 21 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
* Thu Nov 15 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
* Thu Nov 15 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#594
- use exceptions to handle errors
* Wed Nov 14 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#593
- added support to create udf (fate#312911)
- added integration test
- increased so patch number
- handle block size in max_size for udf
* Tue Nov 13 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#592
- added comments for translators
* Sat Nov 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Sat Nov 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Sat Nov 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Sat Nov 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Fri Nov  9 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#591
- extended documentation
* Thu Nov  8 2018 Vojtech.Zeisek@opensuse.org
- Translated using Weblate (Czech)
* Tue Nov  6 2018 antoine.belvire@opensuse.org
- Translated using Weblate (French)
- 4.1.55
* Sat Nov  3 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.54
* Fri Nov  2 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#589
- Add method Luks#get_uuid
* Wed Oct 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
* Wed Oct 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.1.53
* Wed Oct 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 4.1.52
* Wed Oct 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.1.51
* Wed Oct 31 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#588
- Regenerated potfiles
- 4.1.50
* Wed Oct 31 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#585
- Fixed broken autobuild environment
- Support for StrayBlkDevices in CompoundActions (bsc#1085134)
- Moved predicates to base class
- New unit test for Bcache compound actions
- Use new check from superclass
- Removed unnecessary include
- Support for Bcache in CompoundActions
- First (incomplete) CompoundAction formatter for Bcache
- Fixed broken English
- Use inherited methods
- Use actual output for translator examples
- Use multiple lines, not one neverending line
- First complete CompoundAction formatter for Bcache
- First unit test for MD-RAID compound actions
- Added CompoundActions formatter for MD-RAIDs
- More test cases for MD-RAID
- User sanity check
- Coding style cleanup
- Updated year in useless legalese
- Added missing sformat parameter
- Added missing parameter doc in translator comment
- Fixed translator comments
- Moved device list formatting out to separate common function
- Use better comparision function
- Use existing constants
- New CompoundActions
* Mon Oct 29 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#587
- extended documentation
- ported check from snapper
- minor improvements
- 4.1.49
* Mon Oct 29 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#586
- mark AUTHORS as %%doc
* Wed Oct 24 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#584
- mark LICENSE file as license
- 4.1.48
* Tue Oct 23 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#583
- Use predicates to make the code much better readable
- Added missing return
- Use speaking function names for getters
- Moved methods to base class
- Use predicates and speaking getters to make the code much better
  readable (bsc#1085134)
- 4.1.47
* Fri Oct 19 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#582
- make format of po files consistent with gettext
- 4.1.46
* Thu Oct 18 2018 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#580
- add bcache attributes (fate#325346)
- [RFC] add bcache attributes (fate#325346)
- 4.1.45
* Fri Oct 12 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.44
* Wed Oct 10 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#581
- Added test case for weird UUID (bsc#1102572)
- Whitespace
- Fixed blkid output parser to honor escaped quotes (bsc#1102572)
- Fixed blkid output parser to honor escaped quotes
- 4.1.43
* Sun Oct  7 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.1.42
* Fri Oct  5 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
- 4.1.41
* Fri Oct  5 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
* Fri Oct  5 2018 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#579
- Use for bcache cset as display name string "bcache cache"
  (fate#325346)
- 4.1.40
* Tue Oct  2 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#578
- use predefined constants
- 4.1.39
* Tue Oct  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
- 4.1.38
* Thu Sep 27 2018 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#577
- implement searching for free name for bcache (fate#325346)
- 4.1.37
* Wed Sep 26 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.1.36
* Tue Sep 25 2018 lslezak@suse.cz
- merge gh#openSUSE/libstorage-ng#576
- Added Travis ccache documentation
- Added Travis ccache documentation and cache cleanup
- 4.1.35
* Mon Sep 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.34
* Fri Sep 21 2018 lslezak@suse.cz
- merge gh#openSUSE/libstorage-ng#575
- Use ccache in Travis builds
- Use ccache in Travis builds (up to 4x faster)
- 4.1.33
* Mon Sep 17 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#574
- Allow to set Md uuid for testing
- 4.1.32
* Sun Sep 16 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish)
- 4.1.31
* Thu Sep 13 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#573
- extended documentation
- 4.1.30
* Thu Sep 13 2018 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#572
- Allow bcache to have partitions (fate#325346)
- Allow bcache to have partitions
- 4.1.29
* Tue Sep 11 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#571
- do not translate snapshot description (bsc#1092757)
- updated pot und po files
- 4.1.28
* Tue Sep 11 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 4.1.27
* Mon Sep 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 4.1.26
* Mon Sep 10 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#570
- merge gh#openSUSE/libstorage-ng#569
- fixed variable scope to fix temporary mounting (bsc#1099144)
- added unit test
- 4.1.25
* Thu Sep  6 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#568
- avoid setenv after fork (bsc#1107403)
- added unit test
- 4.1.24
* Wed Sep  5 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#567
- added luks label to blkid parser
- added unit test
- 4.1.23
* Sun Sep  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 4.1.22
* Tue Aug 28 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#566
- merge branch SLE-15-GA
- merge gh#openSUSE/libstorage-ng#554
- merge gh#openSUSE/libstorage-ng#565
- merge gh#openSUSE/libstorage-ng#560
- merge gh#openSUSE/libstorage-ng#564
- merge gh#openSUSE/libstorage-ng#562
- detect correctly whether a file system is currently mounted
  (bsc#1105227)
- adjust multipath parser to accept nvme related output
  (bsc#1089353)
- Added some class descriptions
- MdLinks: make it work also when even /dev/md does not exist
- Avoid exceptions for inactive RAIDs (bsc#1090010)
- Fixed the existing tests
- test inactive noncontainer
- detect raid containers differently
- Mark inactive RAID in the BlkDevice attribute
- A common way to configure the indentation style
- Inactive raid
- Merge SLE-15-GA into master
- 4.1.21
* Fri Aug 24 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#560
- adjust multipath parser to accept nvme related output
  (bsc#1089353)
- try to make multipath parser more robust
- add unit tests
- 4.1.20
* Thu Aug 23 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#562
- detect correctly whether a file system is currently mounted
  (bsc#1105227)
- add unit tests
- add spaces
- 4.1.19
* Wed Aug 22 2018 jreidinger@suse.cz
- merge gh#openSUSE/libstorage-ng#563
- do not crash when parsing docker devices (bsc#1104899)
- 4.1.18
* Wed Aug 22 2018 schubi@suse.de
- merge gh#openSUSE/libstorage-ng#561
- Changed licence to GPL-2.0-only.
- 4.1.17
* Tue Aug 21 2018 mvidner@suse.cz
- merge gh#openSUSE/libstorage-ng#548
- RAID: states of operation
- RAID docs: nicer formatting for the older notes
- autodocs: ignore Doxygen search data
- Don't surprise myself.
- 4.1.16
* Tue Aug 14 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.1.15
* Mon Aug 13 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 4.1.14
* Mon Aug 13 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
- 4.1.13
* Mon Aug 13 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 4.1.12
* Fri Aug 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.11
* Thu Aug  9 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.1.10
* Thu Aug  9 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 4.1.9
* Thu Aug  9 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.1.8
* Wed Aug  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Wed Aug  8 2018 aschnell@suse.de
- updated pot and po files
* Wed Aug  8 2018 aschnell@suse.de
- changed pretty name
* Wed Aug  8 2018 aschnell@suse.de
- added documentation
* Wed Aug  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
* Wed Aug  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
* Wed Aug  8 2018 opensuse-packaging@opensuse.org
- merge branch master
- Translated using Weblate (German)
* Tue Aug  7 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#558
- updated pot and po files
- 4.1.7
* Tue Aug  7 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.1.6
* Tue Aug  7 2018 aschnell@suse.de
- extended NameSchema class
- added StrayBlkDevice class (bsc#1085134)
- extended unit tests
- added unit test for probing xen xvd devices
- cleanup
- updated pot and po files
- extended documentation
- 4.1.5
* Tue Aug  7 2018 lslezak@suse.cz
- merge gh#openSUSE/libstorage-ng#557
- Update the "build_dependencies:*" tasks to read the alternative
  spec file
- README.md: libjson-c-devel is needed as well
- Added pkgconfig check for the libjson-c library
- Do not crash when displaying summary for an encrypted but not
  mounted disk (bsc#1099181)
- Added unit test
- Fixed a typo
* Tue Aug  7 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 4.1.4
* Tue Aug  7 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#555
- fix build with glibc 2.28
- 4.1.3
* Tue Aug  7 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#556
- update git2log script to latest version
- 4.1.2
* Sun Aug  5 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 4.1.1
* Tue Jul 31 2018 aschnell@suse.de
- added special handling when creating udev ids starting with
  dm-uuid for partitions on multipath (bsc#1099394)
- use strlen
* Tue Jul 31 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#550
- document package version scheme
* Mon Jul 23 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#546
- document package version scheme
- 4.1.0
* Mon Jul 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#545
- added document for limits
- 3.3.317
* Fri Jul 13 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#544
- work on creating and deleting bcaches
- updated swig catches
- added unit tests
- added integration tests
- reuse code
- cleanup
- 3.3.316
* Tue Jul 10 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#543
- use sysfs path in find_by_any_name()
- 3.3.315
* Mon Jul  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#542
- added support for f2fs (fate#325755)
- added integration test
- removed unused code
- removed obsolete documentation
- 3.3.314
* Mon Jul  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#541
- handle Intel Rapid Start Technology Partition ID (fate#325885)
- extended documentation
- coding style
- 3.3.313
* Tue Jun 26 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#540
- do not use deprecated header file
- coding style
- 3.3.312
* Wed Jun 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#539
- handle device type attribute of udevadm info output
- removed unused and obsolete file
- do not try to activate LUKS on devices used by multipath (bsc#1089699)
- improved explanation
- 3.3.311
* Mon Jun 18 2018 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#538
- Add method BlkDevice#is_active
- 3.3.310
* Tue Jun 12 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#537
- updated unit test
- extended unit test
- fixed exception logging
- 3.3.309
* Tue Jun 12 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
- 3.3.308
* Thu Jun  7 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
- 3.3.307
* Thu Jun  7 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.306
* Thu Jun  7 2018 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#536
- Expose Device#devicegraph (needed for bsc#1094157)
- Encryption#set_dm_table_name adjusts #name (for bsc#1094157 and
  bsc#1094963)
- Code improvement from code review
- More code improvements from code review
- 3.3.305
* Thu Jun  7 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
* Thu Jun  7 2018 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#535
- Return better exception (related to bsc#1094963)
- Fix project name
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.304
* Mon Jun  4 2018 Vojtech.Zeisek@opensuse.org
- Translated using Weblate (Czech)
- 3.3.303
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.302
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.301
* Mon Jun  4 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.300
* Mon Jun  4 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#534
- handle exception (see bsc#1073633)
- 3.3.299
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.298
* Mon Jun  4 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#533
- merged po files
- 3.3.297
* Mon Jun  4 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#532
- improved error handling during probing partitions (see
  bsc#1095168)
- 3.3.296
* Fri Jun  1 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.295
* Fri May 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
- 3.3.294
* Thu May 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.293
* Wed May 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.292
* Tue May 22 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 3.3.291
* Sun May 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
- 3.3.290
* Sun May 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
- 3.3.289
* Fri May 18 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#531
- added helper functions
- place repair action before partition actions
- insert action to repair GPTs if needed (bsc#1092193)
- added unit test
- 3.3.288
* Fri May 18 2018 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#530
- Add conflict with old libdmraid (bsc#1088570)
- 3.3.287
* Fri May 18 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#529
- fix probing of certain nvme systems (bsc#1093684)
- 3.3.286
* Thu May 17 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 3.3.285
* Thu May 17 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.284
* Thu May 17 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.283
* Thu May 17 2018 Vojtech.Zeisek@opensuse.org
- Translated using Weblate (Czech)
- 3.3.282
* Thu May 17 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.281
* Thu May 17 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.280
* Thu May 17 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.279
* Thu May 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#528
- added action to fix undersized GPT
- updated pot file
- merged po files
- 3.3.278
* Tue May 15 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#527
- Use stricter NTFS max label size (bsc#1084867)
- 3.3.277
* Tue May 15 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
- 3.3.276
* Tue May 15 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#526
- improved error message (see bsc#1089554)
- 3.3.275
* Mon May 14 2018 igonzalezsosa@suse.com
- merge gh#openSUSE/libstorage-ng#525
- Fix lt translation
- 3.3.274
* Mon May 14 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
* Mon May 14 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
* Fri May 11 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
* Thu May 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Lithuanian)
- 3.3.273
* Wed May  9 2018 fisiu@opensuse.org
- Translated using Weblate (Polish)
- 3.3.272
* Wed May  9 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.271
* Sun May  6 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Greek)
- 3.3.270
* Sat May  5 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.269
* Fri May  4 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.268
* Thu May  3 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 3.3.267
* Thu May  3 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#524
- fixed probing of NTFS (in special cases) (bsc#1091585)
- added unit test
- 3.3.266
* Wed May  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.265
* Wed May  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.264
* Wed May  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.263
* Mon Apr 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.262
* Sat Apr 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 3.3.261
* Sat Apr 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 3.3.260
* Fri Apr 27 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.259
* Fri Apr 27 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.258
* Fri Apr 27 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.257
* Fri Apr 27 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.256
* Fri Apr 27 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#523
- merged po files
- 3.3.255
* Thu Apr 26 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#522
- centralized reading /sys/block
- added function light_probe (for bsc#1090753)
- added integration test
- 3.3.254
* Wed Apr 25 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#521
- added stand-alone functions to read fstab and crypttab
- added integration tests
- removed unneeded include
- 3.3.253
* Tue Apr 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 3.3.252
* Tue Apr 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.251
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.250
* Mon Apr 23 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#520
- fixed probing of active flag (bsc#1090520)
- improved error handling
- 3.3.249
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Polish)
- 3.3.248
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
- 3.3.247
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.246
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.245
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.244
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
* Mon Apr 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
* Sun Apr 22 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
- 3.3.243
* Sat Apr 21 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.242
* Sat Apr 21 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.241
* Fri Apr 20 2018 antoine.belvire@opensuse.org
- Translated using Weblate (French)
- 3.3.240
* Fri Apr 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
- 3.3.239
* Fri Apr 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#518
- added function to query allowed MD parities (see bsc#1090182)
- 3.3.238
* Fri Apr 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (French)
* Fri Apr 20 2018 weblate-noreply@opensuse.org
- 3.3.237
* Fri Apr 20 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#519
- update git2log script to avoid identical timestamps in changelog
- 3.3.236
* Fri Apr 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
* Fri Apr 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
- 3.3.235
* Fri Apr 20 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.234
* Fri Apr 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
- 3.3.233
* Thu Apr 19 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.232
* Thu Apr 19 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.231
* Thu Apr 19 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.230
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
- 3.3.229
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.228
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
- 3.3.227
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.226
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.225
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.224
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.223
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 3.3.222
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.221
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.220
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
- 3.3.219
* Wed Apr 18 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.218
* Wed Apr 18 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.217
* Wed Apr 18 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#517
- updated documentation
- merged po files (bsc#1089902)
- 3.3.216
* Tue Apr 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#516
- fix unused partition slots calculation for logical partitions
  (bsc#1088483)
- added unit test
- 3.3.215
* Tue Apr 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#515
- use correct options for multipath (see bsc#1089353)
- 3.3.214
* Mon Apr 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#514
- added unit test
- 3.3.213
* Mon Apr 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#513
- keep exception type (bsc#1088570)
- 3.3.212
* Mon Apr 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#512
- handle new mount type variable also in equal, print, ...
- 3.3.211
* Thu Apr 12 2018 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#511
- Add MountPoint#mount_type to XML format (follow up on bsc#1088426)
- 3.3.210
* Tue Apr 10 2018 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#510
- Expose the vfstype field from fstab (bsc#1088426)
- 3.3.209
* Tue Apr 10 2018 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#509
- Force acceptance of SR (fate#318196)
- 3.3.208
* Fri Apr  6 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#508
- added helper function
- support lock within same process
- 3.3.207
* Thu Apr  5 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#507
- added function to set freq and passno
- removed unneeded const
- added documentation
- 3.3.206
* Wed Apr  4 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#506
- added minix to enum of filesystem types
- 3.3.205
* Tue Apr  3 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#505
- enable system-wide lock
- 3.3.204
* Tue Apr  3 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#504
- handle pid_t in bindings
- extended integration test
- 3.3.203
* Wed Mar 28 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#503
- only insert resize action for devices existing in LHS and RHS
  (bsc#1085523)
- added action dependency
- added unit tests
- fixed typo
- added documentation
- 3.3.202
* Mon Mar 26 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#502
- Simplified supplements for lang subpkg (bsc#1081454)
- 3.3.201
* Fri Mar 23 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#501
- make LockException available in API
- 3.3.200
* Wed Mar 21 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#500
- extended documentation
- 3.3.199
* Tue Mar 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#499
- provide reasons why resize is not possible
- added unit tests
- added integration tests
- use more common notation
- 3.3.198
* Tue Mar 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#498
- added workaround for cryptsetup exit code regression (see
  bsc#1082640)
- added convenience function
- 3.3.197
* Mon Mar 19 2018 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#497
- Enable exception
- 3.3.196
* Fri Mar 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#496
- do not recognize 0x1f as extended partition
- 3.3.195
* Fri Mar 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#495
- recognize 0x85 as extended partition
- 3.3.194
* Fri Mar 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#494
- moved enum to storage namespace
- added integration test
- use mdadm to delete MD RAID (see bsc#1085470)
- 3.3.193
* Thu Mar 15 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#493
- export more functions in API
- 3.3.192
* Wed Mar 14 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#492
- handle erroneous small disks in get_unused_partition_slots()
  (bsc#1084777)
- added unit tests
- added note
- 3.3.191
* Tue Mar 13 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#491
- added functions to copy devices and holders between devicegraphs
- 3.3.190
* Mon Mar 12 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#489
- allow to remove partial volume group (bsc#955870)
- updated pot file
- added integration test
- fixed typo
- added convenience function
- removed unused function
- coding style
- handle udev encoding for label in fstab and crypttab
- removed unused define
- added define by /dev/disk paths
- use new defines
- simplyfied code
- coding style
- 3.3.189
* Fri Mar  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#488
- avoid compiler warnings
- removed unused capture
- improved check function
- moved CheckCallbacksRecorder class
- extended unit test
- propagate force_rw flag (bsc#1079000)
- updated documentation
- 3.3.188
* Wed Mar  7 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#487
- handle duplicate LVM PVs during probe
- cleanup
- added unit test
- 3.3.187
* Wed Mar  7 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#486
- split large function
- probe LUKS later
- do not probe LUKS on devices used by multipath (bsc#1079817)
- added unit test
- fixed typo
- 3.3.186
* Tue Mar  6 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#485
- added unit test
- 3.3.185
* Mon Mar  5 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#484
- added unit test
- coding style
- 3.3.184
* Mon Mar  5 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#483
- added note
- improved logging
- try to delete directory before creating btrfs subvolume
- handle change of path in mount point
- added integration test
- handle missing attribute for pvs
- do not search for block device of missing pvs
- improved exception handling
- improved example
- fixed log message
- 3.3.183
* Wed Feb 28 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#482
- added check for existence of devicegraphs
- 3.3.182
* Wed Feb 28 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#481
- always allow to activate multipath (see bsc#1082542)
- 3.3.181
* Wed Feb 28 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#480
- log time in several formats to ease debugging
- 3.3.180
* Tue Feb 27 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#479
- recalculate size of volume group when setting extent size
  (bsc#1079579)
- added unit tests
- coding style
- added documentation
- 3.3.179
* Tue Feb 27 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#478
- generate dot files with more information
- 3.3.178
* Tue Feb 27 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#477
- added callbacks to handle errors during activation (bsc#1057426
  and others)
- updated pot file
- improved integration test
- 3.3.177
* Sun Feb 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.176
* Sun Feb 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.175
* Sat Feb 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish)
- 3.3.174
* Fri Feb 23 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#476
- improved integration tests
- added documentation
- 3.3.173
* Fri Feb 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Ukrainian)
* Thu Feb 22 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish)
- 3.3.172
* Thu Feb 22 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#475
- allow SystemCmd to verify program exit code
- added base class for callbacks
- added callbacks for probing (bsc#1070459 and many others)
- use callbacks base class
- use new verify feature of SystemCmd
- improved error handling
- work on handling errors during probe
- updated pot file
- use callbacks base class
- coding style
- extended documentation
- 3.3.171
* Thu Feb 22 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#474
- fixed device existence check (bsc#1082143)
- 3.3.170
* Wed Feb 21 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#473
- Default to GPT for creating partition tables (fate#323457)
- 3.3.169
* Wed Feb 21 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#472
- insert mount and unmount actions for resize
- added unit tests
- 3.3.168
* Tue Feb 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#471
- fixed parsing /proc/mounts for ntfs
- fixed error handling when ntfsresize fails
- 3.3.167
* Tue Feb 20 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#470
- consistent names
- remove duplicate actions
- added helper functions
- fixed integration test
- adjust existing unit test to so far supported setup
- coding style
- renamed function to reflect recent changes
- 3.3.166
* Mon Feb 19 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#469
- added possible_mount_bys()
- 3.3.165
* Fri Feb 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#468
- use parted with --ignore-busy (see bsc#1058667)
- added convenience functions
- 3.3.164
* Fri Feb 16 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#467
- cleanup
- added integration test
- added jfs support (boo#1078552)
- 3.3.163
* Thu Feb 15 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#466
- improve ruby bindings
- 3.3.162
* Thu Feb 15 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#465
- extended is_usable_as_blk_device()
- 3.3.161
* Thu Feb 15 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#464
- use system devicegraph during probe
* Wed Feb 14 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#463
- added function is_usable_as_blk_device()
- added function is_usable_as_partitionable()
- 3.3.160
* Wed Feb 14 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#462
- added function to immediately activate/deactivate mount point
- added documentation
- code cleanup
- 3.3.159
* Tue Feb 13 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#461
- work on error handling
- added documentation
- coding style
- extended test case
- 3.3.158
* Mon Feb 12 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#460
- Removed unit tests that clash with new glibc number formatting
  (bsc#1079855)
- 3.3.157
* Fri Feb  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#459
- extended unit tests
- added and improved math functions
- do not rely on 80-bit floats (bsc#1078997)
- added unit test
- added note
- 3.3.156
* Fri Feb  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#458
- removed deprecated functions
- updated unit test
- 3.3.155
* Fri Feb  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#457
- improved error logging
- 3.3.154
* Fri Feb  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#454
- allow to set ssh port
- 3.3.153
* Fri Feb  9 2018 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#456
- fetch the full history in travis so the log can be generated
  correctly
- 3.3.152
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.151
* Thu Feb  8 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#453
- added parser for stat
- ignore disks without node in /dev (bsc#1076971)
- coding style
- 3.3.150
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
* Wed Feb  7 2018 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#450
- Ensure not to write malformed /etc/fstab entries (bsc#1066763)
- 3.3.149
* Wed Feb  7 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#451
- work on error handling
- 3.3.148
* Tue Feb  6 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#449
- fixed default value
- 3.3.147
* Tue Feb  6 2018 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#448
- Add GraphvizFlags::DISPLAYNAME to Devicegraph
* Mon Feb  5 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#447
- allow finer control of flags in write_graphviz
* Mon Feb  5 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#446
- use sid as vertex id
* Sat Feb  3 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
* Fri Feb  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Hungarian)
* Fri Feb  2 2018 aschnell@suse.com
- Translated using Weblate (Afrikaans)
* Fri Feb  2 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#444
- added Mountable::remove_mount_point()
* Fri Feb  2 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#443
- added PRETTY_CLASSNAME to GraphvizFlags
* Fri Feb  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
* Thu Feb  1 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#442
- renamed integration tests
- added integration tests
* Thu Feb  1 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan))
* Wed Jan 31 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#441
- added integration test
- added udevadm settle call
* Wed Jan 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
* Wed Jan 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
* Tue Jan 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
* Tue Jan 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
- 3.3.146
* Tue Jan 30 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#439
- start rpcbind before doing NFS mounts
- cleanup
- added integration-test
- 3.3.145
* Tue Jan 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
* Tue Jan 30 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#438
- extended documentation
- 3.3.144
* Tue Jan 30 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#437
- distinguish between mounted and unmounted in supports_shrink/grow
- 3.3.143
* Tue Jan 30 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Korean)
* Mon Jan 29 2018 mvidner@suse.cz
- Fixed an Arabic format string typo
- 3.3.142
* Sun Jan 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
- 3.3.141
* Fri Jan 26 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#436
- added sanity check
- propagate exception to ruby
- 3.3.140
* Fri Jan 26 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#435
- propagate exception to ruby
- 3.3.139
* Fri Jan 26 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.138
* Fri Jan 26 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Fri Jan 26 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.137
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 3.3.136
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Polish)
- 3.3.135
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Polish)
- 3.3.134
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.133
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.132
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.131
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.130
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.129
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.128
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.127
* Wed Jan 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.126
* Wed Jan 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Wed Jan 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.125
* Wed Jan 24 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#431
- Update libstorage-ng.spec.in
- 3.3.124
* Wed Jan 24 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#434
- find crypttab entries by correct block device
- coding style
- removed unused parameters
* Wed Jan 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.123
* Tue Jan 23 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#433
- added helper function
- improved probing of LUKs
- added unit test
- allow to find unused mockups
- removed unused mockups
- use name from crypttab when activating LUKS
- allow to include more information in graphviz output
- removed unused parser
- 3.3.122
* Tue Jan 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.121
* Tue Jan 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
- 3.3.120
* Tue Jan 23 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.119
* Mon Jan 22 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#432
- updated
- 3.3.118
* Sat Jan 20 2018 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#430
- Revert "Add libstorage-ng-lang Recommends"
- 3.3.117
* Sat Jan 20 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#429
- Add libstorage-ng-lang Recommends
- 3.3.116
* Fri Jan 19 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#428
- use /etc/fstab and /proc/mounts for probing NFS
- added NFS unit test
- 3.3.115
* Thu Jan 18 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#427
- extended integration test
- 3.3.114
* Wed Jan 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#426
- fixed alignment calculations
- added unit test
- 3.3.113
* Wed Jan 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#425
- added new align policy KEEP_START_ALIGN_END
- updated unit tests
- updated integration tests
- 3.3.112
* Wed Jan 17 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#424
- propagate exception
- 3.3.111
* Sun Jan 14 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 3.3.110
* Tue Jan  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#423
- updated documentation
- extended documentation
- extended integration test
- added convenience functions
- updated catches file
- added convert function
- added integration test
- 3.3.109
* Tue Jan  9 2018 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#422
- added check for active flag
- coding style
- 3.3.108
* Fri Jan  5 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.107
* Fri Dec 29 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (German)
- 3.3.106
* Fri Dec 22 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#421
- avoid use of cerr
- updated exceptions
- coding style
- avoid use of cout
- 3.3.105
* Wed Dec 20 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.104
* Wed Dec 20 2017 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#420
- remove LIBVERSION_MAJOR macro from spec.in
- 3.3.103
* Wed Dec 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#418
- check divisor prior to modulo operation
- avoid throw in destructor
- 3.3.102
* Wed Dec 20 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#419
- Leave enough space even for 'reiserfs'
- 3.3.101
* Wed Dec 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#416
- added obsoletes (bsc#1073645)
- removed very old obsoletes
- 3.3.100
* Wed Dec 20 2017 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#417
- Explain why virtio udev links are filtered out
* Wed Dec 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#415
- fixed print call
- 3.3.99
* Tue Dec 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#414
- renamed functions
- provide find_by_any_name in API (bsc#1073254)
- updated catches file
- added integration test
- 3.3.98
* Tue Dec 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#413
- disable vfat resize since support from utilility is unclear (see
  bsc#1072479)
- 3.3.97
* Tue Dec 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#412
- switch to python 3
- 3.3.96
* Fri Dec 15 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#410
- added helper function
- added helper class
- added function to compare by subvolume id
- probe active flag for BtrfsSubvolume
- 3.3.95
* Thu Dec 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#409
- also renumber extended partitions
- 3.3.94
* Thu Dec 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#408
- renumber primary partitions (bsc#1072656)
- added unit test
- 3.3.93
* Thu Dec 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#406
- removed sorting of results
- 3.3.92
* Thu Dec 14 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#407
- Install libboost_test
- 3.3.91
* Thu Dec 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#405
- handle active flag
- provide more generic function
- coding style
- set active flag for blk filesystems
- fixed subvolid regex
- added log message
- 3.3.90
* Wed Dec 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.89
* Tue Dec 12 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian)
- 3.3.88
* Mon Dec 11 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#404
- fixed documentation
- 3.3.87
* Fri Dec  8 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.86
* Fri Dec  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#403
- use print as a function
- update examples
- 3.3.85
* Thu Dec  7 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech)
- 3.3.84
* Thu Dec  7 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#402
- improved error message
- 3.3.83
* Wed Dec  6 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Ukrainian)
- 3.3.82
* Mon Dec  4 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#401
- package some utils
- cleanup
- 3.3.81
* Fri Dec  1 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#400
- added helper functions
- sort devices using a sort key
- added unit tests
- remove sorting
- increased library version
- fixed usage text
- avoid endl
- extended documentation
- 3.3.80
* Thu Nov 30 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#399
- increase log line limit
- fixed output format
- 3.3.79
* Tue Nov 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#398
- coding style
- omit pointers
- 3.3.78
* Mon Nov 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#397
- handle improved parted output (bsc#1066467)
- coding style
- 3.3.77
* Mon Nov 27 2017 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#396
- make PartitionTable::is_partition_id_supported() public
- 3.3.76
* Fri Nov 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#395
- removed unused variable
* Thu Nov 23 2017 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#394
- Don't sort disks and dasds by default
* Wed Nov 22 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#393
- added unit test
- 3.3.75
* Wed Nov 22 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#392
- added function to get mount_by method
- remove "none" from crypt options
- get mount-by method from crypttab
- added crypt_options to Encryption class
- improved unit test
- coding style
- coding style
- 3.3.74
* Mon Nov 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#391
- added logging
- 3.3.73
* Sun Nov 19 2017 weblate-noreply@opensuse.org
- 3.3.72
* Fri Nov 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#390
- do not rely on sorting
- added compare by sid function
- 3.3.71
* Thu Nov 16 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#389
- added mount-by variable for encryption
- extended documentation
- use get_mount_by_name for luks
- coding style
- added logging
- 3.3.70
* Wed Nov 15 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#387
- log errors of found by check
- added checks (disabled until yast2-storage-ng is improved)
- coding style
- added missing member variables in print function
- added check
- added documentation
- 3.3.69
* Mon Nov 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 3.3.68
* Fri Nov 10 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
- 3.3.67
* Thu Nov  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#386
- handle pmem prefix during sort
- added unit test
- coding style
- more natural sorting of Mds
- make compare funcions available in API
- added compare function for partitionables
- added unit test
- added integration test
- added test
- 3.3.66
* Tue Nov  7 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#385
- extended documentation (result of bsc#1066290)
- extended test data
- extended test
- 3.3.65
* Mon Nov  6 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#384
- added check for chunk size of MD RAID (see bsc#1065381)
- support RAID 4
- added integration test
- extended integration test
- fixed typo
- 3.3.64
* Sat Nov  4 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.63
* Fri Nov  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#383
- added document about spelling
- consistent spelling
- updated pot file
- 3.3.62
* Fri Nov  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#382
- fixed compound action message (bsc#1066364)
- also extract messages from compount action formatters
- updated pot file
- 3.3.61
* Fri Nov  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#381
- work on exceptions
- 3.3.60
* Fri Nov  3 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
* Thu Nov  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#380
- changed interface of wait_for_devices()
- improved comment
- 3.3.59
* Thu Nov  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#379
- extended documentation
- 3.3.58
* Thu Nov  2 2017 weblate-noreply@opensuse.org
- 3.3.57
* Fri Oct 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#378
- added global function for wait for several devices
- coding style
- wait for devices before swapon (bsc#1064282)
- wait for devices before creating md raid
- wait for devices before pvcreate
- 3.3.56
* Fri Oct 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#377
- probe page size (for bsc#1065381)
- coding style
- 3.3.55
* Fri Oct 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#376
- added udevadm settle calls
- 3.3.54
* Thu Oct 26 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#375
- updated examples
- removed unused code
- unified Python and Ruby bindings
- added examples
- 3.3.53
* Thu Oct 26 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#374
- fixed typo
- coding style
- fixed off-by-one error in max_primary()
- coding style
- fixed max_logical()
- added documentation
- extended unit tests
- added function to create implicit partition
- extended Partitionable constructor
- added unit tests
- added unit tests
- moved code
- work on exceptions
- extended documentation
- consistent wording
- consistent logging
- updated pot-file
- fixed typo
- 3.3.52
* Wed Oct 25 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#373
- work on udev link handling
- 3.3.51
* Tue Oct 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#372
- handle implicit partition table when detecting resize info
- extended query for possible partition tables
- make stream function public available
- added integration test
- no partition slots on implicit partition tables
- specialized messages for creating and deleting partitions
- added unit tests
- improved integrations tests
- updated status.md
- added integration test
- work on exceptions
- 3.3.50
* Mon Oct 23 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#371
- extended documentation
- updated status
- fixed typo
- added hyperlink
- save bus-id in Dasd class
- added example program
- added class ImplicitPt and probing of it
- updated docygen.conf
- updated swig files
- added unit test
- work on exceptions
- extended unused_regions (bsc#1064429)
- use references instead of copies
- fixed typo
- added documentation
- 3.3.49
* Tue Oct 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#370
- dependency handling for thin logical volumes
- unit tests
- 3.3.48
* Mon Oct 16 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#369
- fixed min-size calculation for small filesystems
- added block size parameter to ResizeInfo
- handle new block_size parameter
- implemented get_resize_info for thin pools and thins
- allow to set reserved extents
- added unit tests
- extended integration tests
- smarter resize info calculation
- fixed comment
- 3.3.47
* Fri Oct 13 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#368
- added helper functions
- added functions to calculate default chunk size and metadata size
  for thin pools
- added integration test
- handle lvm pvs without lvm vg during probing
- added note
- added function to query max size for thins
- improved lvs parser
- updated documentation
- added is_overcommitted()
- handle reserved extents
- added checks
- work on exceptions
- improved calculation of used extents
- added max_size_for_lvm_lv
- extended documentation
- added checks
- added unit tests
- work on API of check functions
- updated pot file
- added helper function
- fixed test
- added check
- simpler code
- clearer documentation
- 3.3.46
* Mon Oct  9 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian)
* Mon Oct  9 2017 igonzalezsosa@suse.com
- Adapt SetTuneOptions::commit
- Drop CommitOptions destructor
- Add const to CommitOptions arguments
- Drop unneeded const in CommitOptions
- Mark commit(CommitCallbacks*) as deprecated
- 3.3.45
* Mon Oct  9 2017 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#367
* Mon Oct  9 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.44
* Fri Oct  6 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#366
- work on filesystem tune options
- extended integration tests
- 3.3.43
* Thu Oct  5 2017 igonzalezsosa@suse.com
- merge gh#openSUSE/libstorage-ng#365
- Honor mkfs_options when creating filesystems
- 3.3.42
* Thu Oct  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#364
- handle chunk size
- updated integration tests
- 3.3.41
* Thu Oct  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#363
- added messages for thin pool and thin logical volumes
- 3.3.40
* Mon Oct  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#362
- fixed stripes detection for thin-pools
- set stripes like LVM does
- 3.3.39
* Fri Sep 29 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#361
- get more data from lvs command
- take stripes value from lvs instead of dmsetup
- added chunk_size to LvmLv
- updated unit test
- 3.3.38
* Fri Sep 29 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#360
- extended exception message
- thin volumes cannot be striped
- work on exceptions
- 3.3.37
* Fri Sep 29 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#359
- added unit test
- 3.3.36
* Thu Sep 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#358
- fixed variable name
- 3.3.35
* Thu Sep 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#357
- extended tests
- consistent parameter style
- 3.3.34
* Thu Sep 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#356
- added reserved extents variable
- added documentation
- 3.3.33
* Thu Sep 28 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Lithuanian)
* Wed Sep 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#355
- extended lvs parser
- 3.3.32
* Wed Sep 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#354
- added udevadm settle call
- 3.3.31
* Wed Sep 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#353
- call efibootmgr before deleting partitions
- 3.3.30
* Tue Sep 26 2017 Vojtech.Zeisek@opensuse.org
- Translated using Weblate (Czech)
- 3.3.29
* Tue Sep 26 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#352
- added JsonFile class with simple JSON parser
- use JSON report format for LVM tools
- coding style
- added exception class LvmLvNotFoundByLvName
- added convenience functions
- updated swig catches file
- added integration test
- coding style
- 3.3.28
* Tue Sep 26 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
- 3.3.27
* Mon Sep 25 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#351
- extended lvs parser
- add lv_type to LvmLv
- updated integration tests
- updated swig catches file
- allow to create thin-pools and thins
- added integration test
- do not allow to resize extended partition
- 3.3.26
* Sat Sep 23 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.25
* Fri Sep 22 2017 freek@opensuse.org
- Translated using Weblate (Dutch)
- 3.3.24
* Thu Sep 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#350
- raise global sid if needed during load
- 3.3.23
* Thu Sep 21 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China))
* Tue Sep 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#349
- added helper functions
- provide functions to create/remove encryption while keeping
  children
- added unit tests
- updated swig catches file
- also check devicegraphs
- 3.3.22
* Tue Sep 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#348
- updated documentation
- 3.3.21
* Tue Sep 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#347
- work on querying resize-info
- work on unit tests
- documentation
- coding style
- fixed typo
- 3.3.20
* Fri Sep 15 2017 lslezak@suse.cz
- merge gh#openSUSE/libstorage-ng#345
- Update the scripts from openSUSE/linuxrc-devtools
- Install graphviz as well
- Use .tar.xz format for the source tarball
- Do not use the shared YaST Travis script for building
- 3.3.19
* Fri Sep 15 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#346
- added do_resize for Btrfs
- updated documentation
- cleanup
- cleanup
- 3.3.18
* Thu Sep 14 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil))
* Thu Sep 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#344
- do not clean pot-file
- 3.3.17
* Thu Sep 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#343
- implemented do_resize for Xfs
- 3.3.16
* Wed Sep 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
* Wed Sep 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 3.3.15
* Wed Sep 13 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#339
- Add .snapshots subvolume directly to /etc/fstab, not via the
  external installation-helper command
- Add leading slash to .snapshots subvol name in /etc/fstab
- Inherit mount opts from parent btrfs and add leading slash to
  subvol name
- Reset diff reference after writing the file
- Reset diff reference before change
- 3.3.14
* Wed Sep 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
* Wed Sep 13 2017 aschnell@suse.com
- Translated using Weblate (Finnish)
- 3.3.13
* Wed Sep 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 3.3.12
* Wed Sep 13 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#341
- updated documentation
- 3.3.11
* Wed Sep 13 2017 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
* Wed Sep 13 2017 freek@opensuse.org
- Translated using Weblate (Dutch)
* Wed Sep 13 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#340
- added pot file
- added translation from libstorage
- 3.3.10
* Tue Sep 12 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#338
- coding style
- use --force and --yes more often when using lvm tools
- added integration tests
- also handle action resizing physical volumes
- handle ResizeInfo for lvm pv
- updated swig catches
- 3.3.9
* Mon Sep 11 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#337
- added documentation
- added more combine functions
- added documentation
- make function available in API
- added function to query unused surrounding region
- added unit tests
- fixed some filesystem limits
- coding style
- do not look at filesystem usage for newly created filesystems
- integration tests
- redirect ntfs resize info query to probed devicegraph
- fixed typo
- 3.3.8
* Thu Sep  7 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#336
- changed some requires to suggests
- require parted >= 3.2
- 3.3.7
* Thu Sep  7 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#335
- added function to query minimal number of devices for Md
- added unit tests
- removed unneeded include statements
- 3.3.6
* Wed Sep  6 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#334
- fixed actiongraph generation for deleting partition tables
  (bsc#1056153)
- added unit test
- merged testsuite directories
- 3.3.5
* Tue Sep  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#333
- use parteds 'resizepart' instead of 'resize' command (bsc#931765)
- 3.3.4
* Tue Sep  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#332
- create partitions on GPT with empty name (see bsc#1023818)
- 3.3.3
* Mon Sep  4 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#331
- Configure snapper if snapshots enabled
- Set snapshot feature so snapper packages will be installed
- Fixed docker setup for Travis
- Fixed make_package script (snwint)
- Move snapper config step1 from post-create to pre-mount
- 3.3.2
* Thu Aug 17 2017 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#329
- use linuxrc-devtools tooling for OBS auto-submission
- remove VERSION and libstorage-ng.changes from git repo
- add git2log and make_package scripts
- don't forget to actually create the VERSION file
- point more often to linuxrc-devtools project
- add link to linuxrc-devtools workflow overview
- 3.3.1
* Tue Aug 15 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#328
- fixed license file
* Mon Aug 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#327
- added subsystem deactivate functions
- added deactivate function
- added integration test
- fixed typos
* Fri Aug 11 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#326
- generate Activate and Deactivate actions for BlkDevices
- activate and deactivate actions for LvmLv
- separate deactivation action for Md
- deactivation action for Multipath
- deactivate only active Encryptions
- coding style
- sort partition by number
* Wed Aug  9 2017 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#324
- submit to default YaST project (YaST:Head)
- generate changes file
- set version to 3.3.0
- 3.3.0
* Wed Aug  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#323
- simpler code
* Wed Aug  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#322
- use define
* Tue Aug  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#321
- added exception handling
* Tue Aug  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#320
- support partition ids on dasd partition table
* Tue Aug  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#319
- special dependencies for DASD partition table
- added unit test
- coding style
- fixed typo
* Thu Aug  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#318
- improved activation of Md
* Thu Aug  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#317
- updated paths
* Wed Aug  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#316
- allow independent control of container entries
- also parse MD level in MdadmDetail
- skip parted call on inactive and zero-size devices
- added note
- added MD level "container"
- renamed superblock-version to metadata
- use reference
- recognize imsm and ddf
- set initial MD level to unknown
- probe MD level from mdadm --detail
- coding style
- cleanup
- exception handling
- added MdContainer and MdMember
- added unit tests
- added unit test
- updated documentation
- updated bindings
- updated status
- extended documentation
* Mon Jul 31 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#315
- moved document, fixed typo
* Thu Jul 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#314
- added program to generate downcast file
- regenerated downcast file
- coding style
- fixed test
- added unit tests
- coding style
* Tue Jul 25 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#313
- added program to generate catches file
- updated catches file
* Mon Jul 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#312
- try to fix installation on multipath
* Fri Jul 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#311
- regenerated catches file
* Fri Jul 21 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#310
- Comment some public Region methods
* Fri Jul 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#308
- coding style
- fixed DM RAID activation
- only probe active DM RAIDs
- removed unneeded code
* Thu Jul 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#307
- implemented activation of DM RAID
- updated documentation
* Thu Jul 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#306
- improved dmraid parser
* Mon Jul 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#305
- updated bindings
* Mon Jul 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#304
- added query function
- updated unit tests
- added support for DM RAIDs
- added example program
- fixed typo
- coding style
- added unit test
- extended unit tests
- activate Md before DmRaid
- fixed typo
* Fri Jul 14 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#303
- Expose Alignment#grain
- Expose Alignment#offset
* Wed Jul 12 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#302
- fixed syntax
- work on exceptions
- coding style
- added unit tests
- added unit tests
* Tue Jul 11 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#301
- added functions to set dasd type and format
- consistent function names
* Wed Jun 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#284
- avoid integer overflow
- correct name for unit tests
- extended unit test
- probe multipath devices
- better interface
- extended CmdBlkid for external journal information
- probe external journals devices
- added unit test
- added override
- added support for named MD RAIDs
- added integration tests
- extended unit test
- added unit test
- adapted integration test
- extended documentation
- coding style
- generalised tests
- corrected test
- added documentation
- avoid g++ warning by removing unused code
- added override
- removed unused variable
- added unit test
- renamed get_device et.al. to get_non_impl
- pass mount_by to get_mount_by_name()
- extended unit test
- reduced scope of variable
- added test case
- shorter code
- added documentation
- added special handling for named RAIDs where the name is a number
- added get_all_if for Mds
- added debug messages
- use strongly types enums
- fixed command handling
- reduced interface of SystemCmd
- updated file list
- allow to load mockup
- generalised test
- added function to adjust sids
- extended int
- added query function
- added query function
- coding style
- renamed variables
- renamed library
- renamed variables
- coding style
- improved probing for multipath
- set dm table name for partitions
- set range for partitionables on dm
- updates tests to md level enum change
- simple valid check for multipath names
- added unit tests
- use wider int
- sort udev ids like libstorage does
- include multipath with alias in test case
- added example program
- activate mds
- do not log debug log-level per default
- updated swig catches
- updated documentation
- avoid cycle in actiongraph
- added documentation
- updated swig catches
- fixed file list
- extended documentation
- updated swig catches file
- removed wrong parameter documentation
- coding style
- generate swig catches for some deprecated functions
- enable doxygen xml output (needed for generating swig catches)
- fixed class name
- coding style
- updated list of exception classes
- coding style
- added dependency on doxygen.conf
- provide definition of data member
* Tue Jun 13 2017 tchvatal@suse.com
- merge gh#openSUSE/libstorage-ng#147
- Detect libxml bit more properly to work on most distributions
- Cleanup the spec file to adhere Factory packaging guidelines
- Check for boost headers to ensure configure stops prior build
  failure if the boost-devel is not present
- Split out the boost dependencies up to the latest boost package
  split on openSUSE_Tumbleweed
- Do not require rubygem-test-unit on Factory
- Remove boost-regexp dependency as it was removed in favor of
  higer C++ standard function
* Tue Jun 13 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#283
- fixed function names
* Tue Jun 13 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#282
- reuse existing table of filesystem names
- improved exception message
* Mon Jun 12 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#281
- split directory examples into utils and examples
* Mon Jun 12 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#280
- Fix bug
* Mon Jun 12 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#279
- added used features flag for DASDs
* Fri Jun  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#278
- extended transmogify example
- improved Action::RenameIn ordering for DASDs
- added unit tests
- added documentation
- added bugzilla reference
* Fri Jun  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#277
- updated mockups to use parted --machine
- removed old parted parser
* Thu Jun  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#276
- added check
- do not use cylinder size as block size
- avoid holder two actiongraph in memory
- coding style
- added more comparison operators
- check partition order
- coding style
- added call to check()
- workaround for parted sector size during resize
- handle alignment in partition resize integration tests
- simpler Makefile.am
- renumber partitions on DASD partition table
- added unit-tests
- renamed unit-test
- added integration test
- renamed variable
- fixed typos
* Tue Jun  6 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#259
- WIP
- WIP
- WIP
- Add CompoundActionFormater base class
- Add BtrfsSubvolumeFormater class
- Update gitignore files
- Add NfsFormater class
- Add BtrfsFormater class
- Add LvmLvFormater and LvmVgFormater
- Add compound actions to actiongraph
- Integrate CompoundAction and Actiongraph
- Add bindings for CompoundAction
- Remove old files
- Update gitignore
- Add CompoundAction#is_delete
- Change return of find_by_target_device
- Rename CompoundAction classes
- Use Generator to generate compounds actions
- Simplify CompoundAction creation
- Rename and delete public methods
- Return const objects
- Remove empty destructors and improve constructors
- Fix spelling
- Add methods to LvmLv formatter
- Add methods for LvmVg formatter
- Delete improperly added file
- Update example
- Add automake subdir-objects option
- Throw exception when action is unknown
- Add tests for CompoundAction
- Fix example
- Improve formatters
- Add files for compound actions example
- Improve formatters
- Improve tests
- Improve text for compound actions with swap
- Minor fixes
- Rename data files
- Fix test makefile
- Improve variable names
- Some improvements in formatters
- Add gitignore
- Remove spaces
* Tue Jun  6 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#274
- Add compound actions summary doc
- Fix text
- More text fixes
* Tue Jun  6 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#275
- enhanced get_possible_partition_table_types() for DASDs
- simpler code
* Mon Jun  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#273
- added documentation
- renamed variable and enums
- set extended_slot to false on GPT
- implemented partition slots for DASD partition table
- added unit test
- removed unused function
- use vector instead of list
- added assert
- renamed typename
- added utility function
- added unit tests
- simpler code
- added comment
- added convenience function
- added integration test
- better variable names
* Fri Jun  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#272
- added unit tests
- new parse error tests
- converted unit tests to new parted parser
- removed old code
- added note
- fixed syntax
- updated mockups
* Thu Jun  1 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#271
- recognize parted "diag" flag
- log partition id as hex
* Thu Jun  1 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#270
- added find_by_name for Partitionable
- split Topology class into Topology and Alignment
- set minimal-grain to 0 B for DASDs
- improved integration tests
- set extra alignment for DASD partition table
- fix sectors when calling parted on DASD partition table
- use correct sector size
- nicer check
- keep minimal grain for DASDs
- allow to get Alignment class
- allow to align only to hard requirements
- updated documentation about alignment
- use partition id supported on all partition types
* Wed May 31 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#269
- adapted parted mkpart call for dasd partition table
* Tue May 30 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#268
- allow more control over mockup
- rewrote parted parser including fixing sectors on DASDs
- work on support for DASD partition table
- updated unit-test
- coding style
* Wed May 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#266
- added function to convert partition type to string
* Wed May 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#265
- avoid ambiguous code
- replace own Regex class by C++11 regex
- use C++11 regex instead of boost regex
* Mon May 22 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#264
- fixed human string parser
* Mon May 22 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#263
- use svg for graphs
* Fri May 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#262
- updated
* Thu May 18 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#261
- also allow to display actiongraph
* Wed May 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#260
- allow to keep temporary files
* Thu May 11 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#258
- removed obsolete file
* Wed May 10 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#257
- improved parser
- added test case
* Mon May  8 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#256
- eliminated defects found by coverity
* Fri May  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#255
- updated cleanup lists
* Fri May  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#253
- make delete Filesystem or PartitionTable also delete signatures
  on disk
- modified integration tests
- added nop flag to actions
- added helper function
- set nop flag if btrfs filesystem is also deleted
- extended documentation
- removed unused functionality
* Thu May  4 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#252
- added unit tests
- renamed integration test for consistency
- removed unused variable
- added integration test
- coding style
- handle tense
- removed unneeded function override
* Wed May  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#251
- setup logger
- coding style
* Wed May  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#250
- updated file list
* Tue May  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#249
- fixed documentation
* Tue May  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#248
- added in_etc_crypttab flag
- also provide EtcFstab and EtcCrypttab in SystemInfo
- coding style
- set in_etc_crypttab
- set correct crypt device
- added documentation
* Tue May  2 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#247
- provide version information in bindings
* Fri Apr 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#246
- removed probing in constructor and added probe function
- adapted unit tests
- adapted examples
- adapted integration tests
- fixed comment
- added DEVMAPPERDIR define
- save and load in_etc_fstab
- adapted integration test
* Fri Apr 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#245
- removed inadequate lvm activation
- removed unused code
- improved documentation
- added missing include
- provide begin() and end()
- added function returning number of inactive lvm lvs
- added utility functions
- removed unused code
- activate inactive lvm and luks if desired
- updated bindings
- added integration test
- provide activate function in API
- check callback pointer
- fixed typo
* Thu Apr 27 2017 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#244
- Propagate DifferentBlockSizes through the bindings
* Mon Apr 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#243
- added override
* Mon Apr 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#242
- fixed typo
* Mon Apr 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#241
- added check
* Fri Apr 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#240
- initialize values
- reduced include
* Fri Apr 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#239
- added check
- added unit tests
- updated test
- updated documentation
- updated integration tests
- consistent naming
- added documentation
- added convenience function
- improved integration test
* Thu Apr 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#238
- added convenience function
- removed nfs from dasd probing test
- also remove descendants
- added helper functions
- return const objects
- moved mount point data to dedicated class in devicegraph
- adapted bindings
- adapted example
- adapted integration tests
- added integration test for changeing mount-by method
- added documentation
- adapted unit tests
- consistent naming
- make functions as deprecated
- do not longer allow to create Devicegraph without pointer to Storage
- keep exact signature of deprecated functions
- coding style
- added warning
* Wed Apr 19 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#237
- fixed exception message
- more detailed exception message
- updated xml devicegraphs
* Tue Apr 18 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#236
- more detailed error messages
- added comparison operators
* Fri Apr  7 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#235
- check types to avoid exception
* Wed Apr  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#234
- create parent directory of new subvolume
* Wed Apr  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#233
- document that nested RAIDs are unsupported
* Wed Apr  5 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#232
- added functions to handle default mount-by
- removed obsolete classes
- added documentation
- renamed variable
* Tue Apr  4 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#231
- work on md size calculation
- added documentation
- fixed typo
* Tue Apr  4 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#230
- coding style
- added unit test
- improved function interface
- removed debug output
- install header
* Mon Apr  3 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#229
- probe subvolume id after create
* Fri Mar 31 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#228
- added functions to get source and target of a Holder
- fixed integrations tests
- added integration test
* Thu Mar 30 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#227
- added convenience functions
- minor refactoring
- added unit tests
- added convenience functions
- added integration tests
* Wed Mar 29 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#226
- flush results after each test
- handle spare devices in size calculation
- make a conservative calculation
- improve results output
- fix typo
* Wed Mar 29 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#225
- fixed check
- added test for nested RAIDs
- added workaround for bsc#1030896
- removed debug setting
* Tue Mar 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#224
- added sort-key for devices of MD RAID
* Tue Mar 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#223
- added flag in_etc_mdadm
* Mon Mar 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#222
- create /etc directory when mounting /
* Mon Mar 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#221
- probe some uuids after on disk creation
* Fri Mar 24 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#220
- coding style
- reuse objects EtcFstab, EtcCrypttab and EtcMdadm
- added writing of mdadm.conf
- set partition id
- handle new values in Md::Impl
- probe md-name and uuid
- add tense to CommitData
* Thu Mar 23 2017 opensuse-packaging@opensuse.org
- Fixed line number output for empty ranges
- Unit tests for Diff
- Fixed include path
* Thu Mar 23 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#219
- Added generic diff
- Added log_diff()
- Use log_diff() instead of log()
- Fixed verbose mode
- Fixed out of range segfault
- Prevent diff context at file borders
* Tue Mar 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#218
- added support for DASDs (the block device)
* Tue Mar 21 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#217
- initialize value
* Mon Mar 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#215
- protect mount options since subvol can include spaces
* Mon Mar 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#213
- added btrfs subvolume support
* Mon Mar 20 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#214
- Handle fs type unknown
- New test case for fs type unknown
* Mon Mar 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#212
- initialize value in ctor
- set filename
* Fri Mar 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#211
- cleanup AsciiFile (possible after EtcFstab rewrite)
- use AsciiFile to read fstab for mockup playback and record
* Fri Mar 17 2017 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#210
- Use full filename for fstab and crypttab
- Add missing space in mount command
* Fri Mar 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#209
- changed return type of get_mount_type()
- added compatibility functions
* Thu Mar 16 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#208
- removed unneeded includes
- removed obsolete handling of list
* Thu Mar 16 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#202
- Activate vgs
- Add comment
- Fix indentation
* Thu Mar 16 2017 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#206
- New EtcFstab API
- Methods to maintain correct mount order
- Stricter constness and avoid endless call recursion
- Added missing factory method
- Added MountOpts::clear()
- Unit tests for new EtcFstab class
- Better runtime checks using exceptions
- Tests for checking and fixing mount order
- Added tests for pathological cases
- Make line no. optional during parsing
- Store filename for writing, too
- Removed obsolete tests
- Added EtcCrypttab class
- Don't pad last column
- Remove entry by pointer
- Unit test for EtcCrypttab
- New unit test: Nonexistent crypttab
- Removed cruft
- Don't stop parsing after the first error
- Accept unparsable fs enums as type 'unknown'
- Support for logging contents
- Added missing includes
- Get and set options completely at once
- Use new EtcFstab: StorageImpl
- Use new EtcFstab: ProcMounts
- Use new EtcFstab: Nfs
- Use new EtcCrypttab: Luks
- Use new EtcCrypttab: Mountable and BlkFilesystem
- Use new EtcFstab: XML mocking in testsuite
- Omit 'defaults' for mount opts in XML
- Code review fixes
- Documentation fixes
- Support for mocking during probing
- Fixed unit test data
* Thu Mar  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#200
- split off Mountable from Filesystem
- removed unused variable
- added parsers for btrfs tools
- removed unused functions
- unified comments
- fixed typo
- added missing implementation
- allow mocking of SystemCmds with unstable command-line
- added include
- avoid btrfs in test cases (will need more mockup)
- extended style guide
- added example program
* Tue Mar  7 2017 shundhammer@suse.de
- Imported https://github.com/shundhammer/commented-config-file
  (#199)
* Wed Mar  1 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#197
- added some compile time checks
- renamed macro to avoid name collision
* Tue Feb 28 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#196
- moved code to implementation classes
- removed unneeded virtual in API
- added Encryption::get_all() functions
* Mon Feb 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#195
- added comment
- removed unused enum value
* Mon Feb 27 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#194
- redirect to probed devicegraph in EnsureMounted
* Thu Feb 23 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#192
- tiny code simplifications
- added includes
- make EnsureMounted more generic and work for Filesystem
- added class to parse df output
- added class SpaceInfo
- added function to query nfs mounts
- generalise and move some functions from BlkFilesystem to
  Filesystem
- store SpaceInfo in Filesystem
- cleanup
- added basic NFS support
- coding style
- extended bindings for NFS
- added integration tests
- removed dangerous functions and added comment
- updated python bindings
- added check
- added integration test
- added Nfs::Impl::used_features()
* Mon Feb 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#191
- split off class BlkFilesystem from class Filesystem
- updated testcases
- updated example
- updated documentation
- updated bindings
- updated testcases
- updated integration tests
* Mon Feb 20 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#190
- coding style
- removed abstract class
- use direct parent class
- avoid flushes
* Fri Feb 17 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#189
- detect nilfs2
- cleanup
- shorter code
- coding style
- coding style
- added support for ext2, ext3, reiserfs, iso9660 and udf
- updated bindings to new filesystems
- added integration tests
* Thu Feb 16 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#188
- removed cycle from actiongraph for Luks setup
- cleanup
* Wed Feb 15 2017 jlopez@suse.com
- merge gh#openSUSE/libstorage-ng#187
- Bind exceptions for BlkDevice::get_encryption
* Wed Feb 15 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#186
- fixed shrinking devices
- enable commit
* Tue Feb 14 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#185
- added Encryption::get_type()
- make get_type() in EncryptionImpl virtual
* Fri Feb 10 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#184
- implemented do_rename_in_etc_crypttab()
* Thu Feb  9 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#183
- save sid in devicegraphs
- add dependencies to some actions of children of partition table
- added test case
- added documentation
- use convenience function
* Tue Jan 31 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#180
- added set_number() function
- renumber logical partitions in delete_partition()
- added testcase
- coding style
- added actions to rename entries in fstab and crypttab
- use integration test utils
- implemented rename in fstab
- override function
- allow to skip more steps
- better check
- renamed functions
- reuse code
- the check was correct
- coding style
* Mon Jan 23 2017 lslezak@suse.cz
- Added Travis support (use Docker for building)
* Mon Jan 16 2017 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#179
- fixed swig bindings for used_features()
* Thu Jan 12 2017 shundhammer@suse.de
- Typo: Fixed inconsistent enum prefix (#178)
* Thu Dec 22 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#177
- added move constructor and assignment operator
* Tue Dec 13 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#176
- Make boot flag checks public
* Tue Dec  6 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#175
- turn udev_path into vector (see bsc#1011357)
* Mon Dec  5 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#174
- show base in log for hex
- fixed typo
- added tests
- handle partition id on GPT
- added unit tests
- removed TODO mark
- fixed typo
- DRYer code
- renamed test files
- markdown improvements
- renamed function
* Mon Nov 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#173
- updated history
* Fri Nov 18 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#172
- added interface to query used features
- added bcache to used features
- added unit tests
* Thu Nov 17 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#171
- added convenience functions
* Thu Nov  3 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#170
- make functions public available
* Wed Nov  2 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#169
- added parsing legacy_boot in parted output
- actions for boot, legacy_boot and pmbr_boot
- added integration tests
- updated status document
- removed out-commented code
- extended documentation
* Fri Oct 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#168
- added probing pmbr-boot
- added test case for pmbr boot
* Fri Oct 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#167
- moved setting BOOST_TEST_CATCH_SYSTEM_ERRORS
* Wed Oct 26 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#166
- Added LvmLv.get_all()
* Wed Oct 26 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#165
- added utility function to public API
* Tue Oct 25 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#164
- added convenience functions
- moved template definitions to separate file
* Mon Oct 24 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#163
- added name for partition id
* Fri Oct 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#162
- added test case
- moved test cases
- reuse code
- coding style
- simpler code
- reuse code
- help compiler understand code
- removed workaround
- fixed partition name
- run performance tests as last
- coding style
- allow to set udev path and ids
- set udev path and if when creating partition
- added test case
- updated unit test to include object for partition table
- make logical partitions children of extended partition
- added note and todo
- added checks
- moved unit test
* Tue Oct 18 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#161
- also check udev_path and udev_ids in equal and log_diff
- fixed typo
- omit more udev-ids (use whitelist instead of blacklist)
- added explanatory comment
* Mon Oct 17 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#160
- set default partition id based on partition type
* Mon Oct 17 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#159
- fixed initialization order
- check that function is called on correct devicegraph
* Thu Oct 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#158
- use const unique_ptr for pimpl
- added testcase
- added documentation
* Wed Oct  5 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#157
- renamed class
- removed printing to cout from Actiongraph
- performance improvement
- added performance test
- removed examples with testsuite character
- improved example
* Wed Oct  5 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#156
- updated status document
- include feedback from code review
* Tue Oct  4 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#155
- updated documentation
- added end user example
- fixed typo
- improvements from code review
* Thu Sep 29 2016 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#143
- the dependency fix: updated from the specfile
- specified distribution specific dependencies
- corrected deps on tumbleweed
* Thu Sep 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#154
- handle tense
- handle tense
- throw on logic error
- coding style
- added humanstring example
* Wed Sep 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#153
- fixed temporary check
- quote commit message in log
* Tue Sep 27 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#152
- removed some examples that were initial test programs
* Tue Sep 27 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#151
- cylinder -> sector cleanup
* Fri Sep 23 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#150
- added TmpMount class
- added EnsureMounted class
- use EnsureMounted class
- added note
- name enum strongly typed
- now removed enum entirely
* Wed Sep 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#149
- added convenience function to query Ntfs objects
- added convenience function to query Partitionable objects
* Fri Sep 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#148
- initialise class members
* Fri Sep 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#145
- improved device_exists
- fixed typo
- added support to resize (active) lukses
- added integration tests for luks
- coding style
- moved check function to impls
- added check function for Luks
- added comment
- added unit test for resizing luks
- require to provide filename
- incorporated comments from code review
- ignore generated files
* Tue Sep 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#144
- added UntranslatedText and moved Text to own file
- moded StopWatch to own file
- added documentation
- renamed variable
* Mon Sep 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#142
- fixed lvm vg dependency generation if modify actions exist purely
  on lhs
- coding style
- added convenience function
- added flags to control handling of credentials
- correcter explanation for translators
- use ST_THROW macro
- coding style
- support to create, activate, deactivate and delete Luks
- added encryption handling functions to BlkDevice
- added unit tests
- added integrations tests
- handle tense
- added skeleton actions for crypttab handling
- handle tense
- handle crypttab
* Mon Sep  5 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#141
- use C++11 initialisation
- shorter code
- removed unused check
- coding style
- added reusable sort_by_key function
* Tue Aug 30 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#140
- Added a failing test (TDD) for LVM dependencies
- Bugfixes in Action::Create#add_dependencies
- Dependencies between LVM operations
- Fixes from code review: coding style
- Another complex test for LVM dependencies
- Reusable function to add grouped dependencies
- Added a test for PVs being moved between VGs
- Dependencies for moving PVs between different VGs
- Added note about add_chain cost
* Fri Aug 19 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#139
- added const
- added helper function
- renamed variable
- moved calculating dependencies for creating partitions to
  PartitionTable class
- make vertices in actiongraph stable
* Thu Aug 18 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#138
- renamed function
- indicate only-sync in graph output
* Thu Aug 18 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#137
- also save devicegraphs
- renamed function
- call function in base class
- add dependency for reallot actions
- added unit tests for reallot actions in lvm case
- moved some tests to md subdirectory
- always use svg instead of png
* Wed Aug 17 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#136
- Obsolete again old libstorage
* Tue Aug 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#135
- pass vector by reference
* Tue Aug 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#134
- do not call udevadm info for inactive devices
* Fri Aug 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#133
- fixed output
- set flags for ostream
- probe attr for lvm devices
- added active flag to BlkDevice
* Fri Aug 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#131
- fixed parsing of 'dmsetup table' output if no devices were found
- catch exceptions from Storage constructor
* Mon Aug  8 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#130
- Avoid conflict with old libstorage config file
- Do not obsolete old libstorage in .spec
* Mon Aug  1 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#129
- added functions to query volume group
- wait as late as possible
- added note
- moved detect_resize_info to Device
- provide ResizeInfo for LvmPv
- added override
- generate actions for resizing lvm pvs
- added tests for lvm pv resizing
- added get_size_string()
- inform children (LvmVg and Md) when parent has new region
* Fri Jul 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#128
- format numbers
- handle ResizeInfo in LvmLv
- added functions to find a volume group by the vg-name
- make reallot handling work with Device instead of BlkDevice
- handle reallot for volume groups
- allow to save graphs
- fixed consistency between variable name and partition
* Wed Jul 27 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#127
- added most common lvm actions
- removed obsolete define
- wait as late as possible
- added define
- include size in volume group create/delete text
* Fri Jul 22 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#126
- added override where appropriate
* Fri Jul 15 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#125
- make find by uuid functions non public
- extended comment
* Fri Jul 15 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#124
- sort sids in output for better readability
* Thu Jul 14 2016 shundhammer@suse.de
- Use stdin, not tmp files for passwords (bsc#986971) (#123)
* Tue Jul 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#122
- added convenience functions for lvm
- make delete_partition take a Partition
- removed obsolete code
- shorter code
- added function to delete logical volume
- renamed file
- make doxygen analyse more files
- updated documentation
- activate DEPRECATED define
- consistent function names
* Thu Jul  7 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#121
- added convenience functions for Bcache and BcacheCset
* Wed Jul  6 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#120
- move dm-table-name from Encryption to BlkDevice
- probe stripes and stripe-size
- removed obsolete class
- removed unused functions
- fixed documentation
* Fri Jul  1 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#119
- removed unused functions
* Thu Jun 30 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#118
- also support downcast for bcache classes
* Thu Jun 30 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#117
- added copyright headers
- moved filesystem classes from Devices to new Filesystems directory
* Wed Jun 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#116
- added and renamed examples
- init logger
- prefer vector over list
- detect bcache in blkid output
- renamed output files
- simply call probe_pass_2 for all devices
- extended check function
- added get_string function
- decentralized code
- added bcache probing support
- includes cleanup
- added bcache probing testcase
- added documentation links
* Wed Jun 22 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#115
- extended 'dmsetup table' parser to provide target and stripes
* Tue Jun 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#114
- updated doxygen list of input files
* Tue Jun 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#113
- enable client side searching
* Tue Jun 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#112
- extended lvm parsers
- probe size of luks
- probe size of lvm vg and lv
- added copyright header
- handle new class variables
* Thu Jun 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#111
- add get_partitionable() to API
* Wed Jun 15 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#110
- use new is_valid_name
* Tue Jun 14 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#109
- added is_valid_name for BldDevice
* Mon Jun 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#108
- use fallback lockup
- removed now unused function
* Mon Jun 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#107
- use fallback lookup by major and minor number
* Fri Jun 10 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#106
- corrected order
* Fri Jun 10 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#105
- added note
- added luks probing testcase
* Thu Jun  9 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#104
- extended SystemInfo for encryption
- cleanup
- prefer vector over list
- added luks probing support
- use C++11 range based for
* Thu Jun  9 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#103
- during probing find devices by major and minor number if find my
  name fails
* Wed Jun  8 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#102
- added convenience function
- added unit tests
* Fri Jun  3 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#101
- work on LVM support
- added documentation
- added todo
- added check
- extended check functions
- provide vectors of LVM objects
- added get_lvs function
- added get_lvm_pvs function
- added get_blk_device function
- downcast also LVM objects
- added more convenient functions
* Thu Jun  2 2016 jsrain@suse.cz
- merge gh#openSUSE/libstorage-ng#96
- Added YaST requirements, based on meeting in NUE
- AI formatting
- MD formatting
- More formatting
- comments from review
- comments
- Clarified upgrade from EVMS
* Wed Jun  1 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#100
- added functions to search for lvm devices by uuid
- added BlkDevice::get_all
- cleanup
- sort results of lvm commands
- use get_all function
* Tue May 31 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#99
- added functions any_md, any_lvm and any_luks
- explicit function name
- probe mds only if blkid found some
- added uuid to lvm objects
- added get_all functions
- added testcase
- added parsers for pvs and lvs
* Fri May 27 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#98
- call parted with --wipesignatures when creating partitions
- use long option
- adapted tests
* Tue May 24 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#97
- removed perl bindings (only potential use-case kiwi was rewritten
  in python)
- mark function as override
* Fri Apr 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#95
- initialise and log variable
* Fri Apr 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#94
- allow to set minimal_mbr_gap
* Thu Apr 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#93
- allow to set minimal grain
* Thu Apr 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#92
- added convenience functions
* Thu Apr 28 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#91
- added convenience functions
* Wed Apr 27 2016 aschnell@suse.com
- partition alignment, drop cylinders and geometry, change unit of
  sizes (#85)
* Tue Apr 19 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#89
- Added support to set label and uuid for swap devices
- Allow to change label and UUID of pre-existing partitions
- Fix from code review: ST_THROW
* Wed Apr 13 2016 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#88
- Update TsCmp.cc
- Update .gitignore
* Wed Apr 13 2016 aschnell@suse.com
- merge gh#openSUSE/libstorage-ng#87
- added buildrequires graphviz since doxygen needs it
* Tue Apr 12 2016 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#86
- Added check for PPC PowerNV
* Fri Apr  1 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#84
- Added ID_EFI
* Tue Mar 29 2016 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#83
- swig bindings for Storage::Arch
- include Arch.h in docs and devel package
- fix list include
- automake fix
* Thu Mar 24 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#81
- do not create devicegraph without storage object
- coding style
- added missing includes
- coding style
- coding style
* Wed Mar 23 2016 wfeldt@opensuse.org
- merge gh#openSUSE/libstorage-ng#80
- add documentation on parted partition alignment
- enhance doc according to pr comments
- added details on alignment
* Mon Mar 21 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#79
- removed now unneeded scope operator
* Thu Mar 17 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#78
- Disable changelog check
* Wed Mar 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#77
- added detailed flags for write_graphviz()
* Wed Mar 16 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#76
- added missing include (for whatever version travis/jenkins is
  using)
* Tue Mar 15 2016 opensuse-packaging@opensuse.org
- merge gh#openSUSE/libstorage-ng#75
- clarify dependencies, how to test
* Tue Mar 15 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#74
- detect reducing/extending of devices
- just keep one sorted vector of devices
- added function to remove edge
- added function to remove device
- use exception macros
- allow to add and remove spare devices to md
- added integration tests
- more descriptive parameter names
- coding style
- added comments
- eliminate temporary variable
- added some inline documentation
- reshuffle code
* Fri Mar 11 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#73
- added second link in documentation
- detect faulty devices in MD RAID
- fixed comment
* Thu Mar 10 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#72
- test public interface
- added testcases
* Wed Mar  9 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#71
- added set_range to API
* Wed Mar  9 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#70
- added documentation
- added documentation
* Tue Mar  8 2016 ancor@suse.de
- merge gh#openSUSE/libstorage-ng#69
- Added integration with Jenkins
* Tue Mar  8 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#68
- added document about resizing
- fixed typo
* Tue Mar  8 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#67
- reduce code duplication
- throw exceptions in error case
- also generate pictures of devicegraphs
- renamed function and added comments
* Mon Mar  7 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#66
- avoid code duplication
- added unit test
* Mon Mar  7 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#65
- work on tenses for messages
* Mon Mar  7 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#64
- avoid header file
- use new size constants
- avoid assert
- use exception macro
- no need for postfix
- fixed error handling
- cache, load and save Resize- and ContentInfo
* Thu Mar  3 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#63
- adapted filename to library rename
- make code reusable
- coding style
- init logger
- provide __str__ for more classes
- added missing dependency
- use exception macros
- added is_probed query function
- allow to query resize and content information
* Tue Mar  1 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#62
- avoid code repetition
- updated gitignore
* Mon Feb 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#61
- added Action classes for resize
* Mon Feb 29 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#60
- removed unused functions
- avoid boolean function argument
* Thu Feb 25 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#59
- several adoptions to library name change
* Thu Feb 25 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#58
- drop major and minor number from BlkDevice
* Wed Feb 24 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#57
- rename rpm and library to libstorage-ng
* Wed Feb 24 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#56
- drop bindings for legacy interface
- dropped legacy interface and most/all legacy functions
- renamed enum
* Tue Feb 23 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#55
- added and use LogfileLogger
* Fri Feb 19 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#54
- added downcast function in bindings
* Thu Feb 18 2016 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#53
- Expose get_geometry() / set_geometry() to API
* Thu Feb 18 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#52
- added actions to handle /etc/mdadm.conf
- renamed classes
* Thu Jan 14 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#51
- initialise member variables
- replace cmp_lt_number by compare_by_number
- ignore coverity output directory cov-int
- fixed assert
- use proper function
- use proper functions
- added check for overflow
- replace ParseError by ParseException
- extended testsuite
* Wed Jan 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#50
- more tweaking for broken ruby packaging
* Wed Jan 13 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#49
- make Exception hierarchy available in bindings
- do not expose exception macros in public API
* Tue Jan 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#48
- avoid warning with g++ 5.2.1
* Tue Jan 12 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#47
- removed redundant ";"
- added interface functions to query number of partitions
* Mon Jan 11 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#46
- support probing of Md using Md
- fixed function name
- consistent function/variable name
* Fri Jan  8 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#45
- added get_md_parity_name
- added TODO note
* Fri Jan  8 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#44
- added quote for vector<string>
- moved code to storageitu.py
- fixed documentation
- initialise all member variables
- added basic MD RAID support
- added checks and unit-test
- added DEVDIR macro as requested during code review
- added node about consistent naming
- use strlen instead of fixed value
* Tue Jan  5 2016 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#43
- define sorting of results
- use macro
- shorter code
- do not use legacy file for AC_INIT
- remove function identical to base function
- extended style document
* Wed Dec 23 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#42
- remove interim sync actions
- included suggestions from code-review
* Tue Dec 22 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#41
- renamed classes
- added num_actions()
* Tue Dec 22 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#40
- ensure "one definition rule"
* Mon Dec 21 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#39
- added region.to_value function
- added disk.get_possible_partition_table_types()
- added get_pt_type_name()
- use new ST_THROW macro
- call parted with filesystem type depending on partition id
- do not set numeric partition id on non MSDOS partition tables
- added more fs-types for parted mkpart call
- use define
- better names for partition table types
* Tue Dec 15 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#38
- added Device::remove_descendants()
- moved num_children and num_parents to Impl
- use new exceptions macro
* Tue Dec 15 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#37
- added functions to query partition table type of partition table
  object
* Tue Dec 15 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#36
- added missing include
- use C++11 underlying_type for correctness
- define copy constructor and copy assignment for Region
* Mon Dec 14 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#35
- fixed function name
- added TmpDir class (complied with RAII)
- added Vfat and Ntfs device classes
- removed ntfs-3g naming workarounds
- coding style
- delete copy constructor and assignment operator for Device and
  Holder
- use new ST_THROW macro
* Mon Dec 14 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#34
- moved test files
- extended bindings
- updated test program
- added missing include
- added test programs
- moved test programs
- added options to example probe program
- consistent naming
- avoid casts by using std::function
- added logic check
- use traits to avoid undetected typos
- moved setting compiler flags before AC_PROG_CXX to avoid problems
  with --coverage
- more descriptive exceptions
- moved swig catches statements to own file
- extended unit-test
- test documenting exceptions with doxygen
- use constant
* Wed Dec  9 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#33
- added test case
- added branch coverage example
- call region.empty
- coding style
- moved Exception to Utils
- added test-cases
- made text more comprehensible
- added test-case
- fixed off-by-one error
- robuster test-case
* Tue Dec  8 2015 tgoettlicher@suse.de
- merge gh#openSUSE/libstorage-ng#32
- Add ruby remote probe example
* Mon Dec  7 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#31
- added missing DeviceTraits
- consisting coding style
- avoid warning with clang++
- added and use templates is_device/holder_of_type
* Fri Dec  4 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#30
- don't generate documentation for legacy interface
- added some overall documentation
- documented difference between high- and low-level device graph
  functions
* Fri Dec  4 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#29
- added subgraph and filtered_graph paragraph
* Thu Dec  3 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#28
- use fixture
- added checks for big numbers
- coding style
- removed bogus operator
- removed some asserts now handled via exceptions
- added block-size to Region class
- make Partition create functions take region parameter
* Mon Nov 30 2015 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#27
- Prevent crash upon shutdown (object destruction sequence)
- Added TO DO
* Mon Nov 30 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#26
- fixed file list
* Mon Nov 30 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#25
- more detailed message
- added check
- adapted to api change
- implemented umount/swapoff actions
- replaced specifier deprecated in C++11
- moved Logger to Utils
- added nullptr checks
- added traits for Holders
- work on exception logging
- exception handling for storage::to_partition
- updated examples
* Thu Nov 26 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#24
- fixed Umount and RemoveFstab actions
* Thu Nov 26 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#23
- added functions to convert enums to strings
* Wed Nov 25 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#22
- added Filesystem::get_all()
* Tue Nov 24 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#21
- added const version
- steps towards private Devicegraph::Impl graph
- added convenient functions
- use checker macro
- avoid using Devicegraph::Impl.graph member
* Mon Nov 23 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#20
- make Actiongraph.graph private
- added operator[] and fixed some constness
- added probe mode that write devicegraph
- rename class to reflect concept
- make also graph type private
- added typedefs
- log destruction
* Fri Nov 20 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#19
- use font Arial also for action graph
* Thu Nov 19 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#18
- make Actiongraph part of public interface
* Thu Nov 19 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#17
- also provide non-const relatives functions
- added function to remove a list of devices
- use exception macros
* Wed Nov 18 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#16
- use long named option for readability
* Tue Nov 17 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#15
- added one more 'udevadm settle' call
- use a define for udevadm settle
* Tue Nov 17 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#14
- added logger control functions to new api
- allow Logger test function to also check component
- added documentation
- do not expose symbol
- added constructor (just eye candy)
* Mon Nov 16 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#13
- added to_device_of_type template function
- use new to_device_of_type function
- added testcases
- detailed exception messages
- make exceptions take parameters instead of final message
- remember base filename in exception locations
* Thu Nov 12 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#12
- work on exceptions
* Thu Nov 12 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#11
- prefix include guards
* Tue Nov 10 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#10
- generate bindings before running tests
* Tue Nov 10 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#9
- parallel compile and run of tests
* Tue Nov 10 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#8
- removed unneeded define
* Mon Nov  9 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#7
- set BOOST_TEST_CATCH_SYSTEM_ERRORS=no
* Mon Nov  9 2015 gs@suse.de
- merge gh#openSUSE/libstorage-ng#5
- Added exception classes
- added class SystemCmdException and CommandNotFoundException
- added testsuite helpers
- added unit tests for SystemCmd class
- documented CmdParted class
- improved error reporting with new exception classes don't throw
  exception for all kinds of parted stderr output
- improved error reporting for CmdBtrfs, added CmdBtrfsSubvolumes
  class
- added gpt fix backup
- added files common.cc/.h, added test case parse_empty
- use const string&
- remove do_probe and probe() from CmdBtrfsSubvolumes
- use const string&
- remove common.cc/.h (not needed here), remove systemcmd1.cc (to
  be adapted first)
- added test case parse_bad_device_name, parse_no_devices and
  systemcmd_error
- test case parse_wiped_disk_good added, better test names applied
- test cases for ParseException added
- tests for SystemCmd added - retcode != 0 doesn't work
- ignore non zero exit code
- check for boost version >= 1.58
- add test cases for exceptions
- add TO DO for test cases parse_gpt_enlarge_good and
  parse_gpt_fix_backup_good
* Mon Nov  9 2015 shundhammer@suse.de
- merge gh#openSUSE/libstorage-ng#6
- Added use case document
- Added pseudo code for suggested API
- Use partition_table, not disk directly
- Added multi_boot_pc_with_windows() C++ sample
- use correct exception macro
- added comment
* Thu Oct 22 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#4
- added rules to style guide
- added reasons to use C++11
* Wed Oct 21 2015 aschnell@suse.de
- merge gh#openSUSE/libstorage-ng#3
- updated URLs
- added requirements and how to run unit test
* Fri Oct 16 2015 aschnell@suse.de
- extended comment
* Thu Oct 15 2015 mvidner@suse.cz
- merge gh#openSUSE/libstorage-ng#2
- Enable documentation of the storage_legacy namespace.
- Added brief descriptions to classes.
* Thu Oct 15 2015 mvidner@suse.cz
- merge gh#openSUSE/libstorage-ng#1
- How to compile
- How to make a RPM, code documentation.
* Thu Oct 15 2015 aschnell@suse.com
- make code
* Thu Oct 15 2015 aschnell@suse.de
- added design decisions
* Thu Oct 15 2015 aschnell@suse.de
- added heading
* Thu Oct 15 2015 aschnell@suse.de
- moved style guide to docs
* Tue Oct  6 2015 aschnell@suse.com
- added goals
* Thu Apr 16 2015 aschnell@suse.de
- use C++11 to_string
* Thu Mar 12 2015 aschnell@suse.de
- adapted testcase
* Mon Mar  9 2015 aschnell@suse.de
- moved testsuite compare classes to testsuite directory
* Mon Mar  9 2015 aschnell@suse.de
- make output work with older graphviz versions
* Fri Mar  6 2015 aschnell@suse.de
- added testcase
* Fri Mar  6 2015 aschnell@suse.de
- use back_inserter
* Fri Mar  6 2015 aschnell@suse.de
- make errors in actiongraph testsuite readable
* Thu Mar  5 2015 aschnell@suse.de
- improved test message
* Thu Mar  5 2015 aschnell@suse.de
- moved statement
* Thu Mar  5 2015 aschnell@suse.de
- work on compatibility layer
* Wed Mar  4 2015 aschnell@suse.de
- work on compatibility layer
* Wed Mar  4 2015 aschnell@suse.de
- throw exception instead of returning nullptr
* Wed Mar  4 2015 aschnell@suse.de
- renamed class to avoid likely conflict with keyword
* Wed Mar  4 2015 aschnell@suse.de
- work on compatibility layer
* Tue Mar  3 2015 aschnell@suse.de
- ported interface additions from fate#318392
* Tue Mar  3 2015 aschnell@suse.de
- ported interface additions from fate#318392
* Mon Feb 23 2015 aschnell@suse.de
- build on Fedora 21
* Mon Feb 23 2015 aschnell@suse.de
- sync version numbers with libstorage
* Fri Feb 20 2015 aschnell@suse.de
- mark functions as override
* Thu Feb 19 2015 aschnell@suse.de
- added per action callbacks
* Mon Feb  9 2015 aschnell@suse.de
- adapted enum names
* Fri Feb  6 2015 aschnell@suse.de
- first setting first and last flag on actions
* Fri Feb  6 2015 aschnell@suse.de
- save detailed actiongraph
* Fri Feb  6 2015 aschnell@suse.de
- added commit error callback
* Fri Feb  6 2015 aschnell@suse.de
- display name of partition id in message
* Fri Feb  6 2015 aschnell@suse.de
- fstab actions depend on the root filesystem mounted
* Fri Feb  6 2015 aschnell@suse.de
- place detailed node info in extra line
* Thu Feb  5 2015 aschnell@suse.de
- save libstorage version in output files
* Thu Feb  5 2015 aschnell@suse.de
- added namespace
* Thu Feb  5 2015 aschnell@suse.de
- allow to show details in graphviz output
* Thu Feb  5 2015 aschnell@suse.de
- added compare example which reads devicegraphs
* Thu Feb  5 2015 aschnell@suse.de
- added check for nullptr
* Thu Feb  5 2015 aschnell@suse.de
- don't save empty values
* Thu Feb  5 2015 aschnell@suse.de
- a devicegraph might have no devices or holders
* Thu Feb  5 2015 aschnell@suse.de
- work on strongly typed enums with swig 3.0.0
* Wed Feb  4 2015 aschnell@suse.de
- work on compatibility callbacks
* Wed Feb  4 2015 aschnell@suse.de
- skip nop action
* Wed Feb  4 2015 aschnell@suse.de
- rename devicegraph
* Wed Feb  4 2015 aschnell@suse.de
- install legacy header
* Wed Feb  4 2015 aschnell@suse.de
- added namespace
* Wed Feb  4 2015 aschnell@suse.de
- added include
* Wed Feb  4 2015 aschnell@suse.de
- work on compatibility layer
* Wed Feb  4 2015 aschnell@suse.de
- fixed efi detection
* Wed Feb  4 2015 aschnell@suse.de
- quote device
* Wed Feb  4 2015 aschnell@suse.de
- implemented real get_default_partition_table_type function
* Wed Feb  4 2015 aschnell@suse.de
- add storage backref to Devicegraph
* Wed Feb  4 2015 aschnell@suse.de
- install perl5 bindings into versioned directory
* Wed Feb  4 2015 aschnell@suse.de
- allow access to Arch and set some values
* Wed Feb  4 2015 aschnell@suse.de
- save architecture in Storage object
* Tue Feb  3 2015 aschnell@suse.de
- work on compatibility layer
* Tue Feb  3 2015 aschnell@suse.de
- added dummy functions for default partition table type
* Tue Feb  3 2015 aschnell@suse.de
- implemented create for msdos and gpt
* Tue Feb  3 2015 aschnell@suse.de
- generate bindings for filesystems classes
* Tue Feb  3 2015 aschnell@suse.de
- added btrfs (without multidevice) and xfs
* Tue Feb  3 2015 aschnell@suse.de
- use C++11
* Tue Feb  3 2015 aschnell@suse.de
- work on compatibility layer
* Tue Feb  3 2015 aschnell@suse.de
- added check function to Storage
* Tue Feb  3 2015 aschnell@suse.de
- delegate checking for modify actions
* Mon Feb  2 2015 aschnell@suse.de
- added convert functions
* Mon Feb  2 2015 aschnell@suse.de
- mostly reverted a previously patch
* Mon Feb  2 2015 aschnell@suse.de
- added type query functions
* Mon Feb  2 2015 aschnell@suse.de
- make functions creating partitions also take region
* Mon Feb  2 2015 aschnell@suse.de
- implemented calculating unused partition slots
* Mon Feb  2 2015 aschnell@suse.de
- work on compatibility layer
* Mon Feb  2 2015 aschnell@suse.de
- added partition type parameter to create partition functions
* Fri Jan 30 2015 aschnell@suse.de
- added constructor taking all values
* Fri Jan 30 2015 aschnell@suse.de
- removed functions from interface
* Fri Jan 30 2015 aschnell@suse.de
- added function to count partitions of a specific type
* Fri Jan 30 2015 aschnell@suse.de
- more verbose error message
* Fri Jan 30 2015 aschnell@suse.de
- handle range in Disk
* Fri Jan 30 2015 aschnell@suse.de
- catch exception
* Thu Jan 29 2015 aschnell@suse.de
- allow to create ext4 on disk (without partition)
* Thu Jan 29 2015 aschnell@suse.de
- save files in YaST2 dir
* Thu Jan 29 2015 aschnell@suse.de
- added include
* Thu Jan 29 2015 aschnell@suse.de
- better error handling
* Thu Jan 29 2015 aschnell@suse.de
- log beginning of commit action
* Thu Jan 29 2015 aschnell@suse.de
- wait for device before mkfs
* Thu Jan 29 2015 aschnell@suse.de
- handle rootprefix when writing fstab
* Wed Jan 28 2015 aschnell@suse.de
- set size when setting region
* Wed Jan 28 2015 aschnell@suse.de
- work on compatibility layer
* Wed Jan 28 2015 aschnell@suse.de
- work on compatibility layer
* Wed Jan 28 2015 aschnell@suse.de
- work on compatibility layer
* Wed Jan 28 2015 aschnell@suse.de
- extended compatibility layer
* Wed Jan 28 2015 aschnell@suse.de
- extended compatibility layer
* Wed Jan 28 2015 aschnell@suse.de
- improved messages
* Tue Jan 27 2015 aschnell@suse.de
- work on compatibility layer
* Tue Jan 27 2015 aschnell@suse.de
- added mkfs_options and tune_options
* Tue Jan 27 2015 aschnell@suse.de
- work on compatibility layer
* Tue Jan 27 2015 aschnell@suse.de
- use helper functions
* Tue Jan 27 2015 aschnell@suse.de
- fixed dependency generation
* Tue Jan 27 2015 aschnell@suse.de
- work on compatibility layer
* Mon Jan 26 2015 aschnell@suse.de
- handle mount-by when writing fstab
* Mon Jan 26 2015 aschnell@suse.de
- fixed variable order
* Mon Jan 26 2015 aschnell@suse.de
- extended compatibility layer
* Mon Jan 26 2015 aschnell@suse.de
- added Storage reference to Actiongraph
* Mon Jan 26 2015 aschnell@suse.de
- added functions for rootprefix
* Fri Jan 23 2015 aschnell@suse.de
- added include
* Fri Jan 23 2015 aschnell@suse.de
- added include
* Fri Jan 23 2015 aschnell@suse.de
- create mountpoint directory
* Fri Jan 23 2015 aschnell@suse.de
- write fstab entry
* Fri Jan 23 2015 aschnell@suse.de
- simpler syntax
* Fri Jan 23 2015 aschnell@suse.de
- treat empty fstab opts as "defaults"
* Fri Jan 23 2015 aschnell@suse.de
- fixed typo
* Fri Jan 23 2015 aschnell@suse.de
- improved commit messages
* Fri Jan 23 2015 aschnell@suse.de
- extended tests
* Fri Jan 23 2015 aschnell@suse.de
- moved code from Actions to Devices and added Actions
* Thu Jan 22 2015 aschnell@suse.de
- moved code
* Thu Jan 22 2015 aschnell@suse.de
- added action to format swap
* Thu Jan 22 2015 aschnell@suse.de
- updated testsuite data
* Thu Jan 22 2015 aschnell@suse.de
- added rotational/ssd to Disk
* Thu Jan 22 2015 aschnell@suse.de
- added sysfs-name and -path to BlkDevice
* Thu Jan 22 2015 aschnell@suse.de
- added script to demonstrate remote probing
* Thu Jan 22 2015 aschnell@suse.de
- allow to provide own functions for remote probing
* Wed Jan 21 2015 aschnell@suse.de
- implemented commit callbacks
* Mon Jan 19 2015 aschnell@suse.de
- removed unused Actiongraph declaration
* Mon Jan 19 2015 aschnell@suse.de
- provide getPresentDisks
* Mon Jan 19 2015 aschnell@suse.de
- use C++11 chrono::steady_clock
* Fri Jan 16 2015 aschnell@suse.de
- added simple compatibility for saveDeviceGraph
* Fri Jan 16 2015 aschnell@suse.de
- allow access to new Storage from old StorageInterface
* Fri Jan 16 2015 aschnell@suse.de
- fixed namespace
* Fri Jan 16 2015 aschnell@suse.de
- fixed use of PYTHON_INCLUDES
* Fri Jan 16 2015 aschnell@suse.de
- query perl include paths from perl
* Fri Jan 16 2015 aschnell@suse.de
- read mount-by type from fstab
* Thu Jan 15 2015 aschnell@suse.de
- added convenient functions
* Thu Jan 15 2015 aschnell@suse.de
- install StorageVersion.h
* Thu Jan 15 2015 aschnell@suse.de
- install perl files to vender_site
* Thu Jan 15 2015 aschnell@suse.de
- also use data from /etc/fstab for filesystem probing
* Thu Jan 15 2015 aschnell@suse.de
- fixed namespace
* Thu Jan 15 2015 aschnell@suse.de
- detect mountpoint from /proc/mounts
* Wed Jan 14 2015 aschnell@suse.de
- renamed functions
* Wed Jan 14 2015 aschnell@suse.de
- use udevadm to query udev device links
* Wed Jan 14 2015 aschnell@suse.de
- extended compaitbility code
* Wed Jan 14 2015 aschnell@suse.de
- some rudimentary probing for ext4 and swap
* Wed Jan 14 2015 aschnell@suse.de
- load more data
* Wed Jan 14 2015 aschnell@suse.de
- moved code
* Wed Jan 14 2015 aschnell@suse.de
- print more data
* Wed Jan 14 2015 aschnell@suse.de
- added function to query filesystem type
* Wed Jan 14 2015 aschnell@suse.de
- removed function from public interface
* Tue Jan 13 2015 aschnell@suse.de
- added todo
* Tue Jan 13 2015 aschnell@suse.de
- removed unused code
* Tue Jan 13 2015 aschnell@suse.de
- moved file
* Tue Jan 13 2015 aschnell@suse.de
- cleanup
* Tue Jan 13 2015 aschnell@suse.de
- handle udev path and id in compatibility layer
* Tue Jan 13 2015 aschnell@suse.de
- handle udev path and ids in BlkDevice
* Tue Jan 13 2015 aschnell@suse.de
- use external command to query links
* Tue Jan 13 2015 aschnell@suse.de
- formatting
* Tue Jan 13 2015 aschnell@suse.de
- moved get_classname and print to Impl
* Tue Jan 13 2015 aschnell@suse.de
- improved log_diff output
* Mon Jan 12 2015 aschnell@suse.de
- set verbose for 'make check'
* Mon Jan 12 2015 aschnell@suse.de
- handle gpt enlarge during probing
* Mon Jan 12 2015 aschnell@suse.de
- fixed gpt enlarge detection
* Mon Jan 12 2015 aschnell@suse.de
- also record stderr for mockup
* Mon Jan 12 2015 aschnell@suse.de
- implemented comparing device graphs
* Mon Jan 12 2015 aschnell@suse.de
- removed unused code
* Mon Jan 12 2015 aschnell@suse.de
- clear devicegraph in load
* Mon Jan 12 2015 aschnell@suse.de
- initialise values
* Mon Jan 12 2015 aschnell@suse.de
- removed file
* Mon Jan 12 2015 aschnell@suse.de
- added function to get holder sid pairs
* Fri Jan  9 2015 aschnell@suse.de
- added probe testcase (unfinished)
* Fri Jan  9 2015 aschnell@suse.de
- use external command
* Fri Jan  9 2015 aschnell@suse.de
- added clear function
* Fri Jan  9 2015 aschnell@suse.de
- added testsuite
* Fri Jan  9 2015 aschnell@suse.de
- use external command
* Fri Jan  9 2015 aschnell@suse.de
- pass complete object
* Fri Jan  9 2015 aschnell@suse.de
- allow to set mockup filename
* Thu Jan  8 2015 aschnell@suse.de
- added probe modes to read and write mockup
* Thu Jan  8 2015 aschnell@suse.de
- removed obsolete code (env.var. does not exist anymore)
* Thu Jan  8 2015 aschnell@suse.de
- implemented load and save in Mockup
* Thu Jan  8 2015 aschnell@suse.de
- added testcases for EtcFstab
* Thu Jan  8 2015 aschnell@suse.de
- added mockup mode
* Wed Jan  7 2015 aschnell@suse.de
- moved file
* Wed Jan  7 2015 aschnell@suse.de
- added testcases
* Wed Jan  7 2015 aschnell@suse.de
- added testcases
* Wed Jan  7 2015 aschnell@suse.de
- added testcases
* Wed Jan  7 2015 aschnell@suse.de
- added testcases
* Wed Jan  7 2015 aschnell@suse.de
- moved testsuite for SystemInfo to subdir
* Wed Jan  7 2015 aschnell@suse.de
- added testcase
* Wed Jan  7 2015 aschnell@suse.de
- added testcases
* Wed Jan  7 2015 aschnell@suse.de
- allow mockup for SystemCmd and AsciiFile
* Mon Jan  5 2015 aschnell@suse.de
- added test
* Mon Jan  5 2015 aschnell@suse.de
- use variable
* Fri Jan  2 2015 aschnell@suse.de
- added runtime checks
* Fri Jan  2 2015 aschnell@suse.de
- removed old stuff
* Fri Jan  2 2015 aschnell@suse.de
- added lvm classes
* Fri Jan  2 2015 aschnell@suse.de
- added spec file and utilities
* Fri Jan  2 2015 aschnell@suse.de
- split c and c++ flags
* Fri Jan  2 2015 aschnell@suse.de
- better cleanup
* Fri Jan  2 2015 aschnell@suse.de
- added translations (which are needed for testsuite)
* Fri Jan  2 2015 aschnell@suse.de
- added sysconfig fillup
* Fri Jan  2 2015 aschnell@suse.de
- integrate doxygen
* Fri Jan  2 2015 aschnell@suse.de
- use single location for dependencies
* Fri Jan  2 2015 aschnell@suse.de
- install integration-tests
* Fri Jan  2 2015 aschnell@suse.de
- avoid compiler warnings
* Fri Dec 26 2014 aschnell@suse.de
- ignore generated file
* Fri Dec 26 2014 aschnell@suse.de
- ignore generated file
* Fri Dec 26 2014 aschnell@suse.de
- find local swig bindings
* Fri Dec 26 2014 aschnell@suse.de
- generate file
* Fri Dec 26 2014 aschnell@suse.de
- added source files
* Fri Dec 26 2014 aschnell@suse.de
- added subdir
* Fri Dec 26 2014 aschnell@suse.de
- package test xml file
* Fri Dec 26 2014 aschnell@suse.de
- do not include non-existing file
* Fri Dec 26 2014 aschnell@suse.de
- added missing includes
* Fri Dec 26 2014 aschnell@suse.de
- package test scripts
* Fri Dec 26 2014 aschnell@suse.de
- moved file, generate file
* Tue Dec 23 2014 aschnell@suse.de
- added logging of environment
* Tue Dec 23 2014 aschnell@suse.de
- always create a "probed" devicegraph, even if empty
* Mon Dec 22 2014 aschnell@suse.de
- perl like function name
* Mon Dec 22 2014 aschnell@suse.de
- provide sformat also for plain string
* Mon Dec 22 2014 aschnell@suse.de
- namespace cleanup
* Mon Dec 22 2014 aschnell@suse.de
- namespace cleanup
* Mon Dec 22 2014 aschnell@suse.de
- log probed devicegraph
* Mon Dec 22 2014 aschnell@suse.de
- first integration tests
* Thu Dec 18 2014 aschnell@suse.de
- ignore operator<<
* Thu Dec 18 2014 aschnell@suse.de
- include and namespace fixes
* Wed Dec 17 2014 aschnell@suse.de
- report disk label type
* Wed Dec 17 2014 aschnell@suse.de
- fixed examples (still not all working)
* Wed Dec 17 2014 aschnell@suse.de
- make Region usable for interface
* Wed Dec 17 2014 aschnell@suse.de
- work on providing legacy interface and bindings
* Tue Dec 16 2014 aschnell@suse.de
- provide legacy functions
* Tue Dec 16 2014 aschnell@suse.de
- provide more getters and setters
* Mon Dec 15 2014 aschnell@suse.de
- avoid name conflict in swig generated target languages
* Mon Dec 15 2014 aschnell@suse.de
- fix includes
* Mon Dec 15 2014 aschnell@suse.de
- added testcases
* Fri Dec 12 2014 aschnell@suse.de
- added include
* Thu Dec 11 2014 aschnell@suse.de
- addes testcases
* Thu Dec 11 2014 aschnell@suse.de
- fixed compilation
* Thu Dec 11 2014 aschnell@suse.de
- added testcases
* Thu Dec 11 2014 aschnell@suse.de
- don't crash if no logger was setup
* Thu Dec 11 2014 aschnell@suse.de
- work on probing (design still unsatisfied)
* Wed Dec 10 2014 aschnell@suse.de
- updated gitignore
* Wed Dec 10 2014 aschnell@suse.de
- added include
* Wed Dec 10 2014 aschnell@suse.de
- removed generated file
* Wed Dec 10 2014 aschnell@suse.de
- added names for enum
* Wed Dec 10 2014 aschnell@suse.de
- added function to setup logger
* Wed Dec 10 2014 aschnell@suse.de
- fixed sformat string
* Wed Dec 10 2014 aschnell@suse.de
- added assert
* Wed Dec 10 2014 aschnell@suse.de
- added testcases
* Wed Dec 10 2014 aschnell@suse.de
- cleanup
* Wed Dec 10 2014 aschnell@suse.de
- save label as enum instead of string
* Wed Dec 10 2014 aschnell@suse.de
- added functions child and parent
* Wed Dec 10 2014 aschnell@suse.de
- save proved devicegraph
* Wed Dec 10 2014 aschnell@suse.de
- fix for strongly typed enums
* Wed Dec 10 2014 aschnell@suse.de
- added check
* Wed Dec 10 2014 aschnell@suse.de
- added Msdos device object
* Wed Dec 10 2014 aschnell@suse.de
- coding style
* Wed Dec 10 2014 aschnell@suse.de
- cleanup
* Tue Dec  9 2014 aschnell@suse.de
- copied SystemInfo and some utils from old libstorage
* Tue Dec  9 2014 aschnell@suse.de
- reformatted
* Tue Dec  9 2014 aschnell@suse.de
- use different namespace to avoid conflicts with old libstorage
* Tue Dec  9 2014 aschnell@suse.de
- work on style and bindings
* Mon Dec  8 2014 aschnell@suse.de
- added testcase
* Mon Dec  8 2014 aschnell@suse.de
- work on startup
* Mon Dec  8 2014 aschnell@suse.de
- cleanup
* Mon Dec  8 2014 aschnell@suse.de
- fixed order
* Mon Dec  8 2014 aschnell@suse.de
- work on bindings
* Fri Dec  5 2014 aschnell@suse.de
- work on testsuites
* Fri Dec  5 2014 aschnell@suse.de
- added testcase for perl bindings
* Fri Dec  5 2014 aschnell@suse.de
- use strict in perl examples
* Fri Dec  5 2014 aschnell@suse.de
- renamed testcase
* Fri Dec  5 2014 aschnell@suse.de
- renamed cast functions and use autorename for ruby
* Fri Dec  5 2014 aschnell@suse.de
- work on bindings
* Fri Dec  5 2014 aschnell@suse.de
- work on bindings
* Fri Dec  5 2014 aschnell@suse.de
- added tiny testsuite for ruby bindings
* Fri Dec  5 2014 aschnell@suse.de
- work on exceptions and testsuite
* Thu Dec  4 2014 aschnell@suse.de
- added testsuite for python bindings
* Thu Dec  4 2014 aschnell@suse.de
- fixed sid_t bindings
* Thu Dec  4 2014 aschnell@suse.de
- consistent naming
* Thu Dec  4 2014 aschnell@suse.de
- improved failure message
* Thu Dec  4 2014 aschnell@suse.de
- extended example
* Thu Dec  4 2014 aschnell@suse.de
- renamed INCLUDES to AM_CPPFLAGS
* Thu Dec  4 2014 aschnell@suse.de
- consistency
* Wed Dec  3 2014 aschnell@suse.de
- work on loading and saving device graphs
* Wed Dec  3 2014 aschnell@suse.de
- use template function
* Tue Dec  2 2014 aschnell@suse.de
- moved file
* Tue Dec  2 2014 aschnell@suse.de
- fixed compilation
* Tue Dec  2 2014 aschnell@suse.de
- use enum
* Tue Dec  2 2014 aschnell@suse.de
- added find example
* Tue Dec  2 2014 aschnell@suse.de
- work on loading device graph
* Mon Dec  1 2014 aschnell@suse.de
- fixed variable names
* Mon Dec  1 2014 aschnell@suse.de
- work on saving device graph
* Mon Dec  1 2014 aschnell@suse.de
- split Holder files
* Fri Nov 28 2014 aschnell@suse.de
- renamed function
* Fri Nov 28 2014 aschnell@suse.de
- added getSids function
* Fri Nov 28 2014 aschnell@suse.de
- added Environment class
* Thu Nov 27 2014 aschnell@suse.de
- added main class Storage
* Thu Nov 27 2014 aschnell@suse.de
- added swap function
* Wed Nov 26 2014 aschnell@suse.de
- avoid warning from swig
* Wed Nov 26 2014 aschnell@suse.de
- use enum
* Wed Nov 26 2014 aschnell@suse.de
- work on perl5 bindings
* Wed Nov 26 2014 aschnell@suse.de
- exception handling for bindings
* Tue Nov 25 2014 aschnell@suse.de
- added polymorphism example for ruby and perl
* Tue Nov 25 2014 aschnell@suse.de
- use common swig interface file
* Tue Nov 25 2014 aschnell@suse.de
- added BlkDevice::createFilesystem
* Tue Nov 25 2014 aschnell@suse.de
- make Device and Holder object contructors private, use create
  function instead
* Tue Nov 25 2014 aschnell@suse.de
- removed generated file
* Tue Nov 25 2014 aschnell@suse.de
- work on interface
* Tue Nov 25 2014 aschnell@suse.de
- work on swig bindings
* Tue Nov 25 2014 aschnell@suse.de
- work on swig bindings
* Tue Nov 25 2014 aschnell@suse.de
- work on swig bindings
* Tue Nov 25 2014 aschnell@suse.de
- work on swig bindings
* Mon Nov 24 2014 aschnell@suse.de
- work on bindings (not usable yet)
* Wed Nov 19 2014 aschnell@suse.de
- use impl ptr pattern for DeviceGraph
* Wed Nov 19 2014 aschnell@suse.de
- added back reference to device objects
* Tue Nov 18 2014 aschnell@suse.de
- remove old output files
* Tue Nov 18 2014 aschnell@suse.de
- added helper functions
* Sat Nov 15 2014 aschnell@suse.de
- use impl ptr pattern for Device objects
* Fri Oct 24 2014 aschnell@suse.de
- better module name
* Fri Oct 24 2014 aschnell@suse.de
- check exception message
* Fri Oct 24 2014 aschnell@suse.de
- disallow create/delete of disk, instead have partition table
  object
* Fri Oct 24 2014 aschnell@suse.de
- fixed mount ordering
* Fri Oct 24 2014 aschnell@suse.de
- changed action texts
* Fri Oct 24 2014 aschnell@suse.de
- display device graph
* Fri Oct 24 2014 aschnell@suse.de
- fixed return type
* Thu Oct 23 2014 aschnell@suse.de
- added testcase for dependencies
* Thu Oct 23 2014 aschnell@suse.de
- link to wiki
* Thu Oct 23 2014 aschnell@suse.de
- updated
* Thu Oct 23 2014 aschnell@suse.de
- added nop action for synchronization
* Thu Oct 23 2014 aschnell@suse.de
- removed example now in testsuite
* Thu Oct 23 2014 aschnell@suse.de
- dummy ordering for mount actions
* Thu Oct 23 2014 aschnell@suse.de
- use specific test tools
* Thu Oct 23 2014 aschnell@suse.de
- added testsuite
* Wed Oct 22 2014 aschnell@suse.de
- updated
* Wed Oct 22 2014 aschnell@suse.de
- restructured build stuff
* Wed Oct 22 2014 aschnell@suse.de
- updated build stuff
* Wed Oct 22 2014 aschnell@suse.de
- initial eval
